@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """
 Apply / Revert
 
@@ -8,7 +18,6 @@ starting state (before any "Apply").
 Note that this does not automatically provide a full (multi-step incremental)
 Undo capability.
 """
-from __future__ import absolute_import, print_function
 
 from traits.api import HasTraits, Str, List
 from traitsui.api import Item, View, Handler, HGroup, VGroup, TextEditor
@@ -30,9 +39,9 @@ class ApplyRevert_Handler(Handler):
 class ApplyRevertDemo(HasTraits):
 
     # Trait definitions:
-    input = Str
-    stack = List
-    queue = List
+    input = Str()
+    stack = List()
+    queue = List()
 
     # Traits view definitions:
     traits_view = View(
