@@ -1,17 +1,24 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
-This program demonstrates the use of editors that support <i>history</i>. A
+This program demonstrates the use of editors that support *history*. A
 history is a persistent record of the last 'n' values the user has entered or
 selected for a particular trait.
 
-In order for the history to be recorded correctly, you must specify an <i>id</i>
+In order for the history to be recorded correctly, you must specify an *id*
 for both the Item containing the history editor and the View containing the
 Item.
 
 The maximum number of history entries recorded is specified by the value of
-the history editor's <i>entries</i> trait. If <i>entries</i> is less than or
+the history editor's *entries* trait. If *entries* is less than or
 equal to 0, then a normal, non-history, version of the editor will be used.
 
 A history editor also attempts to restore the last value set as the current
@@ -23,7 +30,6 @@ value it had when the demo was run the previous time.
 
 #-- Imports --------------------------------------------------------------
 
-from __future__ import absolute_import
 from traits.api \
     import HasTraits, Str, File, Directory
 
@@ -35,9 +41,9 @@ from traitsui.api \
 
 class HistoryDemo(HasTraits):
 
-    name = Str
-    file = File
-    directory = Directory
+    name = Str()
+    file = File()
+    directory = Directory()
 
     view = View(
         Item('name',
