@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """
 Edit a List of Strings
 
@@ -6,7 +16,6 @@ displaying lists of strings, or other data that can be logically mapped to a
 list of strings.
 """
 
-from __future__ import absolute_import
 from traits.api import HasTraits, List, Str
 from traitsui.api import View, Item, ListStrEditor
 
