@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """
 Using ArrayViewEditor to display large NumPy arrays in a table.
 
@@ -25,21 +35,20 @@ If the list of 'titles' is empty, no column headers will be displayed.
 If the number of column headers is less than the number of array columns, then
 there are two cases:
 
-    - If (number of array_columns) % (number of titles) == 0, then the titles
-      are used to construct a series of repeating column headers with increasing
-      subscripts (e.g. an (n x 6) array with titles of ['x','y','z'] would
-      result in column headers of: 'x0', 'y0', 'z0', 'x1', 'y1', 'z1').
+- If (number of array_columns) % (number of titles) == 0, then the titles
+  are used to construct a series of repeating column headers with increasing
+  subscripts (e.g. an (n x 6) array with titles of ['x','y','z'] would
+  result in column headers of: 'x0', 'y0', 'z0', 'x1', 'y1', 'z1').
 
-    - In all other cases the titles are used as the column headers for the
-      first set of columns, and the remaining column headers are set to the
-      empty string (e.g. an (n x 5) array with titles of ['x','y','z'] would
-      result in column headers of: 'x', 'y', 'z', '', '').
+- In all other cases the titles are used as the column headers for the
+  first set of columns, and the remaining column headers are set to the
+  empty string (e.g. an (n x 5) array with titles of ['x','y','z'] would
+  result in column headers of: 'x', 'y', 'z', '', '').
 
 Setting 'transpose' to True will logically transpose the input array (e.g. an
 (3 x n) array will be displayed as an (n x 3) array).
 """
 
-from __future__ import absolute_import
 from numpy.random import random
 from traits.api import HasTraits, Array
 from traitsui.api import View, Item
