@@ -1,5 +1,12 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 Demonstrates using a popup view within another view.
@@ -14,22 +21,24 @@ value. If you click anywhere else outside of the pop-up dialog, the pop-up
 dialog will simply disappear, leaving the person's new gender value as is.
 
 The main items of interest in this demo are:
- - The: kind = 'popup' trait set in the PersonHandler View which marks the view
-   as being a popup view.
- - The parent = info.gender.control value passed to the edit_traits method
-   when the popup dialog is created in the object_gender_changed method. This
-   value specifies the control that the popup dialog should be positioned near.
+
+- The: kind = 'popup' trait set in the PersonHandler View which marks the view
+  as being a popup view.
+- The parent = info.gender.control value passed to the edit_traits method
+  when the popup dialog is created in the object_gender_changed method. This
+  value specifies the control that the popup dialog should be positioned near.
 
 Notes:
- - Traits UI will automatically position the popup dialog near the specified
-   control in such a way that the pop-up dialog will not overlay the control
-   and will be entirely on the screen (as long as these two conditions do not
-   conflict).
+
+- This demo only works on the wx backend.
+- Traits UI will automatically position the popup dialog near the specified
+  control in such a way that the pop-up dialog will not overlay the control
+  and will be entirely on the screen (as long as these two conditions do not
+  conflict).
 """
 
 #-- Imports --------------------------------------------------------------
 
-from __future__ import absolute_import
 from traits.api \
     import HasPrivateTraits, Str, Int, Enum, Instance, Button
 
@@ -73,8 +82,8 @@ class PersonHandler(Handler):
 class Person(HasPrivateTraits):
 
     # The person's name, age and gender:
-    name = Str
-    age = Int
+    name = Str()
+    age = Int()
     gender = Enum('Male', 'Female')
 
     # The traits UI view:
