@@ -1,5 +1,12 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 This example demonstrates several different variations on using the
@@ -29,65 +36,65 @@ than a full-fledged slider in space limited applications.
 
 The Traits UI ScrubberEditor works as follows:
 
-  - When the mouse pointer moves over the scrubber, the cursor pointer changes
-    shape to indicate that the field has some additional control behavior.
+- When the mouse pointer moves over the scrubber, the cursor pointer changes
+  shape to indicate that the field has some additional control behavior.
 
-  - The control may optionally change color as well, to visually indicate that
-    the control is 'live'.
+- The control may optionally change color as well, to visually indicate that
+  the control is 'live'.
 
-  - If you simply click on the scrubber, an active text entry field is
-    displayed, where you can type a new value for the trait, then press the
-    Enter key.
+- If you simply click on the scrubber, an active text entry field is
+  displayed, where you can type a new value for the trait, then press the
+  Enter key.
 
-  - If you click and drag while over the scrubber, the value of the trait is
-    modified based on the direction you move the mouse. Right and/or up
-    increases the value, left and/or down decreases the value. Holding the
-    Shift key down while scrubbing causes the value to change by 10 times its
-    normal amount. Holding the Control key down while scrubbing changes the
-    value by 0.1 times its normal amount.
+- If you click and drag while over the scrubber, the value of the trait is
+  modified based on the direction you move the mouse. Right and/or up
+  increases the value, left and/or down decreases the value. Holding the
+  Shift key down while scrubbing causes the value to change by 10 times its
+  normal amount. Holding the Control key down while scrubbing changes the
+  value by 0.1 times its normal amount.
 
-  - Scrubbing is not limited to the area of the scrubber control. You can drag
-    as far as you want in any direction, subject to the maximum limits imposed
-    by the trait or ScrubberEditor definition.
+- Scrubbing is not limited to the area of the scrubber control. You can drag
+  as far as you want in any direction, subject to the maximum limits imposed
+  by the trait or ScrubberEditor definition.
 
 The ScrubberEditor also supports several different style and functional
 variations:
 
-  - The visual default is to display only the special scrubber pointer to
-    indicate to the user that 'scrubber' functionality is available.
+- The visual default is to display only the special scrubber pointer to
+  indicate to the user that 'scrubber' functionality is available.
 
-  - By specifying a 'hover_color' value, you can also have the editor change
-    color when the mouse pointer is over it.
+- By specifying a 'hover_color' value, you can also have the editor change
+  color when the mouse pointer is over it.
 
-  - By specifying an 'active_color' value, you can have the editor change color
-    while the user is scrubbing.
+- By specifying an 'active_color' value, you can have the editor change color
+  while the user is scrubbing.
 
-  - By specifying a 'border_color' value, you can display a solid border around
-    the editor to mark it as something other than an ordinary text field.
+- By specifying a 'border_color' value, you can display a solid border around
+  the editor to mark it as something other than an ordinary text field.
 
-  - By specifying an 'increment' value, you can tell the editor what the normal
-    increment value for the scrubber should be. Otherwise, the editor will
-    calculate the increment value itself. Explicitly specifying an increment
-    can be very useful in cases where the underlying trait has an unbounded
-    value, which makes it difficult for the editor to determine what a
-    reasonable increment value might be.
+- By specifying an 'increment' value, you can tell the editor what the normal
+  increment value for the scrubber should be. Otherwise, the editor will
+  calculate the increment value itself. Explicitly specifying an increment
+  can be very useful in cases where the underlying trait has an unbounded
+  value, which makes it difficult for the editor to determine what a
+  reasonable increment value might be.
 
-  - The editor will also correctly handle traits with dynamic ranges (i.e.
-    ranges whose high and low limits are defined by other traits). Besides
-    correctly handling the range limits, the editor will also adjust the
-    default tooltip to display the current range of the scrubber.
+- The editor will also correctly handle traits with dynamic ranges (i.e.
+  ranges whose high and low limits are defined by other traits). Besides
+  correctly handling the range limits, the editor will also adjust the
+  default tooltip to display the current range of the scrubber.
 
 In this example, several of the variations described above are shown:
 
-  - A simple integer range with default visual cues.
+- A simple integer range with default visual cues.
 
-  - A float range with both 'hover_color' and 'active_color' values specified.
+- A float range with both 'hover_color' and 'active_color' values specified.
 
-  - An unbounded range with a 'border_color' value specified.
+- An unbounded range with a 'border_color' value specified.
 
-  - A dynamic range. This consists of three scrubbers: one
-    to control the low end of the range, one to control the high end, and one
-    that uses the high and low values to determine its range.
+- A dynamic range. This consists of three scrubbers: one
+  to control the low end of the range, one to control the high end, and one
+  that uses the high and low values to determine its range.
 
 For comparison purposes, the example also shows the same traits displayed using
 their default editors.
@@ -95,7 +102,6 @@ their default editors.
 
 #-- Imports --------------------------------------------------------------
 
-from __future__ import absolute_import
 from traits.api \
     import HasTraits, Range, Float
 
@@ -117,7 +123,7 @@ class ScrubberDemo(HasTraits):
     # Define some sample ranges and values:
     simple_integer = Range(0, 100)
     rollover_float = Range(-10.0, 10.0)
-    bordered_unbounded = Float
+    bordered_unbounded = Float()
     dynamic_low = Range(high=-0.01, value=-10.0)
     dynamic_high = Range(low=0.01, value=10.0)
     dynamic_value = Range('dynamic_low', 'dynamic_high', 0.0)
