@@ -1,11 +1,18 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 This demo shows you how to use animated GIF files in a traits user interface.
+Note that this demo only works with wx backend.
 """
 
-from __future__ import absolute_import
 from os.path import join, dirname, abspath
 
 from traits.api import HasTraits, File, Bool
