@@ -1,11 +1,17 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """ Demo showing how to use the Windows specific Flash editor.
 """
 
 # Imports:
-from __future__ import absolute_import
 from traitsui.wx.extra.windows.flash_editor \
     import FlashEditor
 
