@@ -1,39 +1,54 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 Implementation of a CheckListEditor demo plugin for the Traits UI demo program.
 
 For each of three CheckListEditor column formations, this demo shows
 each of the four styles of the CheckListEditor.
+
+Please refer to the `CheckListEditor API docs`_ for further information.
+
+.. _CheckListEditor API docs: https://docs.enthought.com/traitsui/api/traitsui.editors.check_list_editor.html#traitsui.editors.check_list_editor.CheckListEditor
 """
 
-# Imports:
-from __future__ import absolute_import
-from traits.api \
-    import HasTraits, List
+from traits.api import HasTraits, List
+
+from traitsui.api import Item, Group, View, CheckListEditor
 
-from traitsui.api \
-    import Item, Group, View, CheckListEditor
 
 # Define the demo class:
-
-
 class CheckListEditorDemo(HasTraits):
     """ Define the main CheckListEditor demo class. """
 
     # Define a trait for each of three formations:
-    checklist_4col = List(editor=CheckListEditor(
-        values=['one', 'two', 'three', 'four'],
-        cols=4))
+    checklist_4col = List(
+        editor=CheckListEditor(
+            values=['one', 'two', 'three', 'four'],
+            cols=4
+        )
+    )
 
-    checklist_2col = List(editor=CheckListEditor(
-        values=['one', 'two', 'three', 'four'],
-        cols=2))
+    checklist_2col = List(
+        editor=CheckListEditor(
+            values=['one', 'two', 'three', 'four'],
+            cols=2
+        )
+    )
 
-    checklist_1col = List(editor=CheckListEditor(
-        values=['one', 'two', 'three', 'four'],
-        cols=1))
+    checklist_1col = List(
+        editor=CheckListEditor(
+            values=['one', 'two', 'three', 'four'],
+            cols=1
+        )
+    )
 
     # CheckListEditor display with four columns:
     cl_4_group = Group(
@@ -71,9 +86,9 @@ class CheckListEditorDemo(HasTraits):
         label='1-column'
     )
 
-    # The view includes one group per column formation.  These will be displayed
-    # on separate tabbed panels.
-    view1 = View(
+    # The view includes one group per column formation.  These will be
+    # displayed on separate tabbed panels.
+    traits_view = View(
         cl_4_group,
         cl_2_group,
         cl_1_group,
@@ -82,6 +97,7 @@ class CheckListEditorDemo(HasTraits):
         resizable=True
     )
 
+
 # Create the demo:
 demo = CheckListEditorDemo()
 
