@@ -1,5 +1,12 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 Demonstrates the use of the TitleEditor.
@@ -10,23 +17,23 @@ the view.
 
 This demonstration shows three variations of using a TitleEditor:
 
- * In the first example, the TitleEditor values are supplied by an Enum trait.
-   Simply select a new value for the title from the drop-down list to cause the
-   title to change.
- * In the second example, the TitleEditor values are supplied by a Str trait.
-   Simply type a new value into the title field to cause the title to change.
- * In the third example, the TitleEditor values are supplied by a Property
-   whose value is derived from a calculation on a Float trait. Type a number
-   into the value field to cause the title to changed.
+* In the first example, the TitleEditor values are supplied by an Enum trait.
+  Simply select a new value for the title from the drop-down list to cause the
+  title to change.
+* In the second example, the TitleEditor values are supplied by a Str trait.
+  Simply type a new value into the title field to cause the title to change.
+* In the third example, the TitleEditor values are supplied by a Property
+  whose value is derived from a calculation on a Float trait. Type a number
+  into the value field to cause the title to changed.
+
+Please refer to the `TitleEditor API docs`_ for further information.
+
+.. _TitleEditor API docs: https://docs.enthought.com/traitsui/api/traitsui.editors.title_editor.html#traitsui.editors.title_editor.TitleEditor
 """
 
-# Imports:
-from __future__ import absolute_import
-from traits.api \
-    import HasTraits, Enum, Str, Float, Property, cached_property
+from traits.api import HasTraits, Enum, Str, Float, Property, cached_property
 
-from traitsui.api \
-    import View, VGroup, HGroup, Item, TitleEditor
+from traitsui.api import View, VGroup, HGroup, Item, TitleEditor
 
 
 class TitleEditorDemo(HasTraits):
@@ -43,13 +50,13 @@ class TitleEditorDemo(HasTraits):
     title_2 = Str('Type into the text field below to change this title')
 
     # A title driven by the result of a calculation:
-    title_3 = Property(depends_on='value')
+    title_3 = Property(observe='value')
 
     # The number used to drive the calculation:
-    value = Float
+    value = Float()
 
     # Define the test view:
-    view = View(
+    traits_view = View(
         VGroup(
             VGroup(
                 HGroup(
@@ -88,16 +95,23 @@ class TitleEditorDemo(HasTraits):
         width=0.4
     )
 
-    #-- Property Implementations ---------------------------------------------
+    # -- Property Implementations ---------------------------------------------
 
     @cached_property
     def _get_title_3(self):
-        try:
-            return ('The square root of %s is %s' %
-                    (self.value, self.value ** 0.5))
-        except:
-            return ('The square root of %s is %si' %
-                    (self.value, (-self.value) ** 0.5))
+        if self.value >= 0:
+            return (
+                'The square root of {} is {}'.format(
+                    self.value, self.value ** 0.5
+                )
+            )
+        else:
+            return (
+                'The square root of {} is {}i'.format(
+                    self.value, (-self.value) ** 0.5
+                )
+            )
+
 
 # Create the demo:
 demo = TitleEditorDemo()
