@@ -3,13 +3,13 @@
 
 # override_editor.py --- Example of overriding a trait
 #                        editor
-from __future__ import absolute_import
-from traits.api import HasTraits, Trait, Color
-from traitsui.api import ColorEditor
+from traits.api import HasTraits, Trait
+from traitsui.api import Color, ColorEditor
 
 
 class Polygon(HasTraits):
     line_color = Trait(Color((0, 0, 0)),
                        editor=ColorEditor())
 
+
 Polygon().configure_traits()
