@@ -3,17 +3,17 @@
 
 # view_attributes.py --- Example of a view as an
 #                        attribute of a class
-from __future__ import absolute_import
 from traits.api import HasTraits, Int, Str, Trait
 from traitsui.api import View
 
 
 class Person(HasTraits):
-    first_name = Str
-    last_name = Str
-    age = Int
+    first_name = Str()
+    last_name = Str()
+    age = Int()
     gender = Trait(None, 'M', 'F')
     name_view = View('first_name', 'last_name')
 
+
 bill = Person()
 bill.configure_traits()
