@@ -3,20 +3,19 @@
 
 # view_multi_object.py --- Example of a view for
 #                          editing multiple objects
-from __future__ import absolute_import
 import wx
-from traits.api import HasTraits, Int, Str, Trait
+from traits.api import HasTraits, Str
 from traitsui.api import View
-import traitsui
 
 
 class Person(HasTraits):
-    first_name = Str
-    last_name = Str
+    first_name = Str()
+    last_name = Str()
 
 
 class Company(HasTraits):
-    company_name = Str
+    company_name = Str()
+
 
 # Standalone View object referencing objects in the UI context
 employee_view = View('e.first_name', 'e.last_name',
