@@ -78,7 +78,6 @@ the browser to display the page defined by the new value of the trait.
 
 #--[Imports]--------------------------------------------------------------
 
-from __future__ import absolute_import
 from traitsui.wx.extra.windows.ie_html_editor \
     import IEHTMLEditor
 
@@ -97,10 +96,10 @@ class WebPage(HasTraits):
     url = Str('http://code.enthought.com')
 
     # The page title:
-    title = Str
+    title = Str()
 
     # The page status:
-    status = Str
+    status = Str()
 
     # The browser navigation buttons:
     back = Button('<--')
