@@ -25,7 +25,6 @@ or float value.
 
 #--[Imports]--------------------------------------------------------------
 
-from __future__ import absolute_import
 from threading \
     import Thread
 
@@ -81,10 +80,10 @@ class LEDDemoHandler(Handler):
 class LEDDemo(HasTraits):
 
     # A counter to display:
-    counter1 = Int
+    counter1 = Int()
 
     # A floating point value to display:
-    counter2 = Float
+    counter2 = Float()
 
     # The traits view:
     view = View(
