@@ -37,7 +37,6 @@ related trait and property definitions in the adapter class itself.
 
 #--<Imports>--------------------------------------------------------------
 
-from __future__ import absolute_import
 import traits
 import traitsui
 
@@ -76,11 +75,11 @@ search_path = [join(dirname(traitsui.api.__file__),
 
 class FileInfo(HasPrivateTraits):
 
-    file_name = File
-    name = Property
-    size = Property
-    time = Property
-    date = Property
+    file_name = File()
+    name = Property()
+    size = Property()
+    time = Property()
+    date = Property()
 
     @cached_property
     def _get_name(self):
@@ -116,9 +115,9 @@ class FileInfoAdapter(TabularAdapter):
     size_alignment = Str('right')
     time_alignment = Str('right')
     date_alignment = Str('right')
-    big_text = Str
+    big_text = Str()
     big_width = Float(18)
-    big_image = Property
+    big_image = Property()
 
     def _get_big_image(self):
         size = self.item.size
@@ -143,10 +142,10 @@ tabular_editor = TabularEditor(
 
 class PythonBrowser(HasPrivateTraits):
 
-    dir = Directory
+    dir = Directory()
     files = List(FileInfo)
     file_info = Instance(FileInfo)
-    code = Code
+    code = Code()
 
     view = View(
         HSplit(
