@@ -1,7 +1,13 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-from __future__ import absolute_import
 from traits.api import *
 from traitsui.api import *
 from traitsui.instance_choice import InstanceChoice
@@ -17,8 +23,8 @@ class Person(HasStrictTraits):
     #  Trait definitions:
     #-------------------------------------------------------------------------
 
-    name = Str
-    age = Int
+    name = Str()
+    age = Int()
     phone = Regex(value='000-0000', regex='\d\d\d[-]\d\d\d\d')
 
     #-------------------------------------------------------------------------
@@ -53,7 +59,7 @@ class Team(HasStrictTraits):
     #  Trait definitions:
     #-------------------------------------------------------------------------
 
-    name = Str
+    name = Str()
     captain = Instance(Person)
     roster = List(Person)
 
