@@ -1,7 +1,13 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-from __future__ import absolute_import
 from traits.api import HasTraits, Float, List
 from traitsui.api import View, Item, RangeEditor
 
@@ -10,7 +16,7 @@ from traitsui.api import View, Item, RangeEditor
 
 
 class TestRangeEditor(HasTraits):
-    x = Float
+    x = Float()
     low = Float(123.123)
     high = Float(1123.123)
     list = List(Float(
