@@ -1,22 +1,19 @@
-#-------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  TableEditor test case for Traits UI which tests editing of lists instead of
-#  editing of objects.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  Written by: David C. Morrill
-#
-#  Date: 07/06/2005
-#
-#  (c) Copyright 2005 by Enthought, Inc.
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
-#
-#-------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
+""" TableEditor test case for Traits UI which tests editing of lists instead
+of editing of objects."""
 
 #-------------------------------------------------------------------------
 #  Imports:
 #-------------------------------------------------------------------------
-from __future__ import absolute_import, print_function
 
 from traits.api \
     import HasStrictTraits, List
@@ -68,7 +65,7 @@ class TableTest(HasStrictTraits):
     #  Trait definitions:
     #-------------------------------------------------------------------------
 
-    people = List
+    people = List()
 
     #-------------------------------------------------------------------------
     #  Traits view definitions:
