@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # Test for TextEditor 'invalid' trait.
 #
 # Look for:
@@ -7,16 +17,15 @@
 #
 #   background color should be set at initialization.
 
-from __future__ import absolute_import
 from traits.api import Bool, HasTraits, Property, Str
 from traitsui.api import Item, View
 from traitsui.api import TextEditor
 
 
 class Person(HasTraits):
-    name = Str
+    name = Str()
 
-    invalid = Property(Bool, depends_on='name')
+    invalid = Property(Bool, observe='name')
 
     def _get_invalid(self):
         # Name is valid iff it doesn't consist entirely of whitespace.
