@@ -1,23 +1,16 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 # Adding this statement for backwards compatibility (since editors.py was a
 # file prior to version 3.0.3).
 
-from __future__ import absolute_import
 
 try:
     from .api import ArrayEditor
@@ -34,6 +27,7 @@ from .api import (
     CompoundEditor,
     CustomEditor,
     DateEditor,
+    DatetimeEditor,
     DefaultOverride,
     DirectoryEditor,
     DNDEditor,
@@ -65,4 +59,5 @@ from .api import (
     ScrubberEditor,
     TabularEditor,
     ProgressEditor,
-    SearchEditor)
+    SearchEditor,
+)
