@@ -1,59 +1,59 @@
-#-------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2008, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   02/29/2008
-#
-#-------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """  Defines adapter interfaces for use with the ListStrEditor.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
+from traits.api import (
+    Any,
+    Bool,
+    Enum,
+    Event,
+    HasPrivateTraits,
+    Int,
+    Interface,
+    List,
+    Str,
+    observe,
+    provides,
+)
+from .toolkit_traits import Color
 
-from __future__ import absolute_import
 
-from traits.api import (Any, Bool, Color, Enum, Event, HasPrivateTraits, Int,
-                        Interface, List, Str, on_trait_change, provides)
-import six
-
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'IListStrAdapter' interface:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class IListStrAdapter(Interface):
 
     #: The index of the current item being adapted.
-    index = Int
+    index = Int()
 
     #: Current item being adapted.
-    item = Any
+    item = Any()
 
     #: The current value (if any).
-    value = Any
+    value = Any()
 
     #: Does the adapter know how to handle the current *item* or not?
-    accepts = Bool
+    accepts = Bool()
 
     #: Does the value of *accepts* depend only upon the type of *item*?
-    is_cacheable = Bool
+    is_cacheable = Bool()
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'AnIListStrAdapter' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 @provides(IListStrAdapter)
 class AnIListStrAdapter(HasPrivateTraits):
@@ -61,13 +61,13 @@ class AnIListStrAdapter(HasPrivateTraits):
     # Implementation of the IListStrAdapter Interface ------------------------
 
     #: The index of the current item being adapted.
-    index = Int
+    index = Int()
 
     #: Current item being adapted.
-    item = Any
+    item = Any()
 
     #: The current value (if any).
-    value = Any
+    value = Any()
 
     #: Does the adapter know how to handle the current *item* or not?
     accepts = Bool(True)
@@ -76,9 +76,10 @@ class AnIListStrAdapter(HasPrivateTraits):
     is_cacheable = Bool(True)
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'ListStrAdapter' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 class ListStrAdapter(HasPrivateTraits):
     """ The base class for adapting list items to values that can be edited
@@ -88,10 +89,10 @@ class ListStrAdapter(HasPrivateTraits):
     # Trait Definitions ------------------------------------------------------
 
     #: Specifies the default value for a new list item.
-    default_value = Any('')
+    default_value = Any("")
 
     #: Specifies the default text for a new list item.
-    default_text = Str
+    default_text = Str()
 
     #: The default text color for even list items.
     even_text_color = Color(None, update=True)
@@ -119,21 +120,21 @@ class ListStrAdapter(HasPrivateTraits):
 
     #: Specifies where a dropped item should be placed in the list relative to
     #: the item it is dropped on.
-    dropped = Enum('after', 'before')
+    dropped = Enum("after", "before")
 
     #: The index of the current item being adapter.
-    index = Int
+    index = Int()
 
     #: The current item being adapted.
-    item = Any
+    item = Any()
 
     #: The current value (if any).
-    value = Any
+    value = Any()
 
     #: List of optional delegated adapters.
     adapters = List(IListStrAdapter, update=True)
 
-    #-- Private Trait Definitions --------------------------------------------
+    # -- Private Trait Definitions --------------------------------------------
 
     #: Cache of attribute handlers.
     cache = Any({})
@@ -141,28 +142,29 @@ class ListStrAdapter(HasPrivateTraits):
     #: Event fired when the cache is flushed.
     cache_flushed = Event(update=True)
 
-    #-- Adapter methods that are sensitive to item type ----------------------
+    # -- Adapter methods that are sensitive to item type ----------------------
 
     def get_can_edit(self, object, trait, index):
         """ Returns whether the user can edit a specified *object.trait[index]*
             list item. A True result indicates the value can be edited, while
             a False result indicates that it cannot be edited.
         """
-        return self._result_for('get_can_edit', object, trait, index)
+        return self._result_for("get_can_edit", object, trait, index)
 
     def get_drag(self, object, trait, index):
         """ Returns the 'drag' value for a specified *object.trait[index]*
-            list item. A result of *None* means that the item cannot be dragged.
+            list item. A result of *None* means that the item cannot be
+            dragged.
         """
-        return self._result_for('get_drag', object, trait, index)
+        return self._result_for("get_drag", object, trait, index)
 
     def get_can_drop(self, object, trait, index, value):
         """ Returns whether the specified *value* can be dropped on the
-            specified *object.trait[index]* list item. A value of **True** means
-            the *value* can be dropped; and a value of **False** indicates that
-            it cannot be dropped.
+            specified *object.trait[index]* list item. A value of **True**
+            means the *value* can be dropped; and a value of **False**
+            indicates that it cannot be dropped.
         """
-        return self._result_for('get_can_drop', object, trait, index, value)
+        return self._result_for("get_can_drop", object, trait, index, value)
 
     def get_dropped(self, object, trait, index, value):
         """ Returns how to handle a specified *value* being dropped on a
@@ -174,20 +176,20 @@ class ListStrAdapter(HasPrivateTraits):
             'after'
                 Insert the specified *value* after the dropped on item.
         """
-        return self._result_for('get_dropped', object, trait, index, value)
+        return self._result_for("get_dropped", object, trait, index, value)
 
     def get_text_color(self, object, trait, index):
         """ Returns the text color for a specified *object.trait[index]* list
             item. A result of None means use the default list item text color.
         """
-        return self._result_for('get_text_color', object, trait, index)
+        return self._result_for("get_text_color", object, trait, index)
 
     def get_bg_color(self, object, trait, index):
         """ Returns the background color for a specified *object.trait[index]*
             list item. A result of None means use the default list item
             background color.
         """
-        return self._result_for('get_bg_color', object, trait, index)
+        return self._result_for("get_bg_color", object, trait, index)
 
     def get_image(self, object, trait, index):
         """ Returns the name of the image to use for a specified
@@ -195,20 +197,20 @@ class ListStrAdapter(HasPrivateTraits):
             should be used. Otherwise, the result should either be the name of
             the image, or an ImageResource item specifying the image to use.
         """
-        return self._result_for('get_image', object, trait, index)
+        return self._result_for("get_image", object, trait, index)
 
     def get_item(self, object, trait, index):
         """ Returns the value of the *object.trait[index]* list item.
         """
-        return self._result_for('get_item', object, trait, index)
+        return self._result_for("get_item", object, trait, index)
 
     def get_text(self, object, trait, index):
         """ Returns the text to display for a specified *object.trait[index]*
             list item.
         """
-        return self._result_for('get_text', object, trait, index)
+        return self._result_for("get_text", object, trait, index)
 
-    #-- Adapter methods that are not sensitive to item type ------------------
+    # -- Adapter methods that are not sensitive to item type ------------------
 
     def len(self, object, trait):
         """ Returns the number of items in the specified *object.trait* list.
@@ -261,18 +263,18 @@ class ListStrAdapter(HasPrivateTraits):
         """ Inserts a new value at the specified *object.trait[index]* list
             index.
         """
-        getattr(object, trait)[index: index] = [value]
+        getattr(object, trait)[index:index] = [value]
 
-    #-- Private Adapter Implementation Methods -------------------------------
+    # -- Private Adapter Implementation Methods -------------------------------
 
     def _get_can_edit(self):
         return self.can_edit
 
     def _get_drag(self):
-        return six.text_type(self.item)
+        return str(self.item)
 
     def _get_can_drop(self):
-        return isinstance(self.value, six.string_types)
+        return isinstance(self.value, str)
 
     def _get_dropped(self):
         return self.dropped
@@ -296,9 +298,9 @@ class ListStrAdapter(HasPrivateTraits):
         return self.item
 
     def _get_text(self):
-        return six.text_type(self.item)
+        return str(self.item)
 
-    #-- Private Methods ------------------------------------------------------
+    # -- Private Methods ------------------------------------------------------
 
     def _result_for(self, name, object, trait, index, value=None):
         """ Returns/Sets the value of the specified *name* attribute for the
@@ -313,7 +315,7 @@ class ListStrAdapter(HasPrivateTraits):
             self.item = item = items[index]
 
         item_class = item.__class__
-        key = '%s:%s' % (item_class.__name__, name)
+        key = "%s:%s" % (item_class.__name__, name)
         handler = self.cache.get(key)
         if handler is not None:
             return handler()
@@ -327,10 +329,10 @@ class ListStrAdapter(HasPrivateTraits):
             if adapter.accepts and (adapter.trait(trait_name) is not None):
                 handler = lambda: getattr(
                     adapter.trait_set(
-                        index=self.index,
-                        item=self.item,
-                        value=self.value),
-                    trait_name)
+                        index=self.index, item=self.item, value=self.value
+                    ),
+                    trait_name,
+                )
 
                 if adapter.is_cacheable:
                     break
@@ -338,18 +340,18 @@ class ListStrAdapter(HasPrivateTraits):
                 return handler()
         else:
             for klass in item_class.__mro__:
-                cname = '%s_%s' % (klass.__name__, trait_name)
+                cname = "%s_%s" % (klass.__name__, trait_name)
                 if self.trait(cname) is not None:
                     handler = lambda: getattr(self, cname)
                     break
             else:
-                handler = getattr(self, '_' + name)
+                handler = getattr(self, "_" + name)
 
         self.cache[key] = handler
         return handler()
 
-    @on_trait_change('adapters.+update')
-    def _flush_cache(self):
+    @observe("adapters.items.+update")
+    def _flush_cache(self, event):
         """ Flushes the cache when any trait on any adapter changes.
         """
         self.cache = {}
