@@ -1,4 +1,14 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,45 +18,45 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Implements a wrapper around the PyQt clipboard that handles Python objects
 using pickle.
 """
 
-from __future__ import absolute_import
 from pyface.qt import QtGui
 from pyface.ui.qt4.mimedata import PyMimeData, str2bytes
 from traits.api import HasTraits, Instance, Property
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  '_Clipboard' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+
 
 class _Clipboard(HasTraits):
     """ The _Clipboard class provides a wrapper around the PyQt clipboard.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # The instance on the clipboard (if any).
-    instance = Property
+    #: The instance on the clipboard (if any).
+    instance = Property()
 
-    # Set if the clipboard contains an instance.
-    has_instance = Property
+    #: Set if the clipboard contains an instance.
+    has_instance = Property()
 
-    # The type of the instance on the clipboard (if any).
-    instance_type = Property
+    #: The type of the instance on the clipboard (if any).
+    instance_type = Property()
 
-    # The application clipboard.
+    #: The application clipboard.
     clipboard = Instance(QtGui.QClipboard)
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Instance property methods:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _get_instance(self):
         """ The instance getter.
@@ -76,17 +86,18 @@ class _Clipboard(HasTraits):
 
         return md.instanceType()
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Other trait handlers:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _clipboard_default(self):
         """ Initialise the clipboard.
         """
         return QtGui.QApplication.clipboard()
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  The singleton clipboard instance.
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 clipboard = _Clipboard()
