@@ -1,4 +1,14 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
 #
@@ -8,42 +18,35 @@
 
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """ Defines the various color editors for the PyQt user interface toolkit.
 """
 
-from __future__ import absolute_import, division
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
 from pyface.qt import QtCore, QtGui
 
-from traitsui.editors.color_editor \
-    import ToolkitEditorFactory as BaseToolkitEditorFactory
+from traitsui.editors.color_editor import (
+    ToolkitEditorFactory as BaseToolkitEditorFactory,
+)
 
-from .editor_factory \
-    import SimpleEditor as BaseSimpleEditor, \
-    TextEditor as BaseTextEditor, \
-    ReadonlyEditor as BaseReadonlyEditor
+from .editor_factory import (
+    SimpleEditor as BaseSimpleEditor,
+    TextEditor as BaseTextEditor,
+    ReadonlyEditor as BaseReadonlyEditor,
+)
 
-from .editor \
-    import Editor
-import six
+from .editor import Editor
 
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
 
 # Standard color samples:
 color_samples = []
 
-#---------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
 #  The PyQt ToolkitEditorFactory class.
-#---------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
 
 ## We need to add qt4-specific methods to the editor factory (since all editors
 ## will be accessing these functions. Making these functions global functions
@@ -55,31 +58,19 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
     """ PyQt editor factory for color editors.
     """
 
-    #-------------------------------------------------------------------------
-    #  Gets the PyQt color equivalent of the object trait:
-    #-------------------------------------------------------------------------
-
     def to_qt4_color(self, editor):
         """ Gets the PyQt color equivalent of the object trait.
         """
         if self.mapped:
-            return getattr(editor.object, editor.name + '_')
+            return getattr(editor.object, editor.name + "_")
 
         return getattr(editor.object, editor.name)
 
-    #-------------------------------------------------------------------------
-    #  Gets the application equivalent of a PyQt value:
-    #-------------------------------------------------------------------------
-
     def from_qt4_color(self, color):
         """ Gets the application equivalent of a PyQt value.
         """
         return color
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #-------------------------------------------------------------------------
-
     def str_color(self, color):
         """ Returns the text representation of a specified color value.
         """
@@ -87,17 +78,20 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
             alpha = color.alpha()
             if alpha == 255:
                 return "(%d,%d,%d)" % (
-                    color.red(), color.green(), color.blue())
+                    color.red(),
+                    color.green(),
+                    color.blue(),
+                )
 
             return "(%d,%d,%d,%d)" % (
-                color.red(), color.green(), color.blue(), alpha)
+                color.red(),
+                color.green(),
+                color.blue(),
+                alpha,
+            )
 
         return color
 
-#-------------------------------------------------------------------------
-#  'SimpleColorEditor' class:
-#-------------------------------------------------------------------------
-
 
 class SimpleColorEditor(BaseSimpleEditor):
     """ Simple style of color editor, which displays a text field whose
@@ -105,10 +99,6 @@ class SimpleColorEditor(BaseSimpleEditor):
     a dialog box for selecting a new color value.
     """
 
-    #-------------------------------------------------------------------------
-    #  Invokes the pop-up editor for an object trait:
-    #-------------------------------------------------------------------------
-
     def popup_editor(self):
         """ Invokes the pop-up editor for an object trait.
         """
@@ -117,71 +107,43 @@ class SimpleColorEditor(BaseSimpleEditor):
         if not self.factory.use_native_dialog:
             options |= QtGui.QColorDialog.DontUseNativeDialog
         color = QtGui.QColorDialog.getColor(
-            color,
-            self.control,
-            u'Select Color',
-            options,
+            color, self.control, "Select Color", options
         )
 
         if color.isValid():
             self.value = self.factory.from_qt4_color(color)
             self.update_editor()
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
-        super(SimpleColorEditor, self).update_editor()
+        super().update_editor()
         set_color(self)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, color):
         """ Returns the text representation of a specified color value.
         """
         return self.factory.str_color(color)
 
-#-------------------------------------------------------------------------
-#  'CustomColorEditor' class:
-#-------------------------------------------------------------------------
-
 
 class CustomColorEditor(Editor):
     """ Custom style of color editor, which displays a color editor panel.
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
         self.control, self._simple_field = color_editor_for(self, parent)
 
-    #-------------------------------------------------------------------------
-    #  Disposes of the contents of an editor:
-    #-------------------------------------------------------------------------
-
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
-        if getattr(self, '_simple_field', None) is not None:
+        if getattr(self, "_simple_field", None) is not None:
             self._simple_field.dispose()
             self._simple_field = None
-        super(CustomColorEditor, self).dispose()
-
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
+        super().dispose()
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -189,81 +151,48 @@ class CustomColorEditor(Editor):
         """
         self._simple_field.update_editor()
 
-    #-------------------------------------------------------------------------
-    #  Updates the object trait when a color swatch is clicked:
-    #-------------------------------------------------------------------------
-
     def update_object_from_swatch(self, color_text):
         """ Updates the object trait when a color swatch is clicked.
         """
-        color = QtGui.QColor(*[int(part) for part in color_text.split(',')])
+        color = QtGui.QColor(*[int(part) for part in color_text.split(",")])
         self.value = self.factory.from_qt4_color(color)
         self.update_editor()
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, color):
         """ Returns the text representation of a specified color value.
         """
         return self.factory.str_color(color)
 
-#-------------------------------------------------------------------------
-#  'TextColorEditor' class:
-#-------------------------------------------------------------------------
-
 
 class TextColorEditor(BaseTextEditor):
     """ Text style of color editor, which displays a text field whose
     background color is the color value.
     """
 
-    #-------------------------------------------------------------------------
-    #  Handles the user changing the contents of the edit control:
-    #-------------------------------------------------------------------------
-
     def update_object(self):
         """ Handles the user changing the contents of the edit control.
         """
-        self.value = six.text_type(self.control.text())
+        self.value = str(self.control.text())
         set_color(self)
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
-        super(TextColorEditor, self).update_editor()
+        super().update_editor()
         set_color(self)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, color):
         """ Returns the text representation of a specified color value.
         """
         return self.factory.str_color(color)
 
-#-------------------------------------------------------------------------
-#  'ReadonlyColorEditor' class:
-#-------------------------------------------------------------------------
-
 
 class ReadonlyColorEditor(BaseReadonlyEditor):
     """ Read-only style of color editor, which displays a read-only text field
     whose background color is the color value.
     """
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -271,29 +200,22 @@ class ReadonlyColorEditor(BaseReadonlyEditor):
         self.control = QtGui.QLineEdit()
         self.control.setReadOnly(True)
 
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
-        super(ReadonlyColorEditor, self).update_editor()
+        super().update_editor()
         set_color(self)
 
-    #-------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #-------------------------------------------------------------------------
-
     def string_value(self, color):
         """ Returns the text representation of a specified color value.
         """
         return self.factory.str_color(color)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #   Sets the color of the specified editor's color control:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 def set_color(editor):
@@ -304,16 +226,17 @@ def set_color(editor):
 
     pal.setColor(QtGui.QPalette.Base, color)
 
-    if (color.red() > 192 or color.blue() > 192 or color.green() > 192):
+    if color.red() > 192 or color.blue() > 192 or color.green() > 192:
         pal.setColor(QtGui.QPalette.Text, QtCore.Qt.black)
     else:
         pal.setColor(QtGui.QPalette.Text, QtCore.Qt.white)
 
     editor.control.setPalette(pal)
 
-#----------------------------------------------------------------------------
+
+# ----------------------------------------------------------------------------
 #  Creates a custom color editor panel for a specified editor:
-#----------------------------------------------------------------------------
+# ----------------------------------------------------------------------------
 
 
 class FixedButton(QtGui.QPushButton):
@@ -342,7 +265,8 @@ def color_editor_for(editor, parent):
     panel.setContentsMargins(0, 0, 0, 0)
 
     swatch_editor = editor.factory.simple_editor(
-        editor.ui, editor.object, editor.name, editor.description, None)
+        editor.ui, editor.object, editor.name, editor.description, None
+    )
     swatch_editor.prepare(parent)
     panel.addWidget(swatch_editor.control)
 
@@ -370,7 +294,7 @@ def color_editor_for(editor, parent):
         for c in range(cols):
             control = FixedButton()
             color = color_samples[r * cols + c]
-            color_text = '%d,%d,%d,%d' % color.getRgb()
+            color_text = "%d,%d,%d,%d" % color.getRgb()
             control.setStyleSheet(sheet_template % color_text)
             control.setAttribute(QtCore.Qt.WA_LayoutUsesWidgetRect, True)
 
@@ -382,7 +306,7 @@ def color_editor_for(editor, parent):
 
             i += 1
 
-    mapper.mapped[six.text_type].connect(editor.update_object_from_swatch)
+    mapper.mapped[str].connect(editor.update_object_from_swatch)
 
     panel.addLayout(grid)
 
