@@ -1,23 +1,18 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2009, Enthought, Inc.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Evan Patterson
-# Date: 06/26/09
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A renderer which displays a checked-box for a True value and an unchecked
     box for a false value.
 """
 
 # System library imports
-from __future__ import absolute_import
 from pyface.qt import QtCore, QtGui
 
 # ETS imports
@@ -29,15 +24,17 @@ class CheckboxRenderer(TableDelegate):
         unchecked box for a false value.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  QAbstractItemDelegate interface
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def editorEvent(self, event, model, option, index):
         """ Reimplemented to handle mouse button clicks.
         """
-        if event.type() == QtCore.QEvent.MouseButtonRelease and \
-                event.button() == QtCore.Qt.LeftButton:
+        if (
+            event.type() == QtCore.QEvent.MouseButtonRelease
+            and event.button() == QtCore.Qt.LeftButton
+        ):
             column = index.model()._editor.columns[index.column()]
             obj = index.data(QtCore.Qt.UserRole)
             checked = bool(column.get_raw_value(obj))
@@ -62,8 +59,9 @@ class CheckboxRenderer(TableDelegate):
                 color_group = QtGui.QPalette.Active
             else:
                 color_group = QtGui.QPalette.Inactive
-            bg_brush = option.palette.brush(color_group,
-                                            QtGui.QPalette.Highlight)
+            bg_brush = option.palette.brush(
+                color_group, QtGui.QPalette.Highlight
+            )
         else:
             bg_brush = index.data(QtCore.Qt.BackgroundRole)
             if bg_brush == NotImplemented or bg_brush is None:
@@ -80,19 +78,25 @@ class CheckboxRenderer(TableDelegate):
 
         # Align the checkbox appropriately.
         box.rect = option.rect
-        size = style.sizeFromContents(QtGui.QStyle.CT_CheckBox, box,
-                                      QtCore.QSize(), None)
+        size = style.sizeFromContents(
+            QtGui.QStyle.CT_CheckBox, box, QtCore.QSize(), None
+        )
         box.rect.setWidth(size.width())
         margin = style.pixelMetric(QtGui.QStyle.PM_ButtonMargin, box)
         alignment = column.horizontal_alignment
-        if alignment == 'left':
+        if alignment == "left":
             box.rect.setLeft(option.rect.left() + margin)
-        elif alignment == 'right':
+        elif alignment == "right":
             box.rect.setLeft(option.rect.right() - size.width() - margin)
         else:
             # FIXME: I don't know why I need the 2 pixels, but I do.
-            box.rect.setLeft(option.rect.left() + option.rect.width() // 2 -
-                             size.width() // 2 + margin - 2)
+            box.rect.setLeft(
+                option.rect.left()
+                + option.rect.width() // 2
+                - size.width() // 2
+                + margin
+                - 2
+            )
 
         # We mark the checkbox always active even when not selected, so
         # it's clear if it's ticked or not on OSX. See bug #439
@@ -111,5 +115,6 @@ class CheckboxRenderer(TableDelegate):
         """
         box = QtGui.QStyleOptionButton()
         style = QtGui.QApplication.instance().style()
-        return style.sizeFromContents(QtGui.QStyle.CT_CheckBox, box,
-                                      QtCore.QSize(), None)
+        return style.sizeFromContents(
+            QtGui.QStyle.CT_CheckBox, box, QtCore.QSize(), None
+        )
