@@ -1,37 +1,22 @@
-#-------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright(c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   08/21/2009
-#
-#-------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines a text editor which displays a text field and maintains a history
     of previously entered values.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
 from pyface.qt import QtGui
 
 from .editor import Editor
-import six
 
-#-------------------------------------------------------------------------
-#  '_HistoryEditor' class:
-#-------------------------------------------------------------------------
 
 
 class _HistoryEditor(Editor):
@@ -40,9 +25,9 @@ class _HistoryEditor(Editor):
         specified by the 'entries' trait of the HistoryEditor factory.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  'Editor' interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -58,7 +43,7 @@ class _HistoryEditor(Editor):
         if self.factory.auto_set:
             control.editTextChanged.connect(self.update_object)
         else:
-            control.activated[six.text_type].connect(self.update_object)
+            control.activated[str].connect(self.update_object)
 
         self.set_tooltip()
 
@@ -66,7 +51,7 @@ class _HistoryEditor(Editor):
         """ Handles the user entering input data in the edit control.
         """
         if not self._no_update:
-            self.value = six.text_type(text)
+            self.value = str(text)
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -76,16 +61,16 @@ class _HistoryEditor(Editor):
         self.control.setEditText(self.str_value)
         self._no_update = False
 
-    #-- UI preference save/restore interface ---------------------------------
+    # -- UI preference save/restore interface ---------------------------------
 
     def restore_prefs(self, prefs):
         """ Restores any saved user preference information associated with the
             editor.
         """
-        history = prefs.get('history')
+        history = prefs.get("history")
         if history:
             self._no_update = True
-            self.control.addItems(history[:self.factory.entries])
+            self.control.addItems(history[: self.factory.entries])
 
             # Adding items sets the edit text, so we reset it afterwards:
             self.control.setEditText(self.str_value)
@@ -95,8 +80,10 @@ class _HistoryEditor(Editor):
     def save_prefs(self):
         """ Returns any user preference information associated with the editor.
         """
-        history = [str(self.control.itemText(index))
-                   for index in range(self.control.count())]
+        history = [
+            str(self.control.itemText(index))
+            for index in range(self.control.count())
+        ]
 
         # If the view closed successfully, update the history with the current
         # editor value, as long it is different from the current object value:
@@ -105,11 +92,11 @@ class _HistoryEditor(Editor):
             if current != self.str_value:
                 history.insert(0, current)
 
-        return {'history': history}
+        return {"history": history}
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  '_HistoryEditor' private interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _truncate(self, parent, start, end):
         """ Handle items being added to the combo box. If there are too many,
