@@ -1,34 +1,33 @@
-#-------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   08/05/2009
-#
-#-------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Traits UI editor for editing lists of strings.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
-
-from __future__ import absolute_import
-from pyface.qt import QtCore, QtGui
-import collections
+import collections.abc
 
 from pyface.image_resource import ImageResource
-from traits.api import Any, Bool, Event, Int, Instance, List, \
-    Property, Str, TraitListEvent, NO_COMPARE
+from pyface.qt import QtCore, QtGui, is_qt5
+
+from traits.api import (
+    Any,
+    Bool,
+    Event,
+    Int,
+    Instance,
+    List,
+    Property,
+    Str,
+    TraitListEvent,
+    NO_COMPARE,
+)
 from traitsui.list_str_adapter import ListStrAdapter
 
 from .editor import Editor
@@ -36,73 +35,66 @@ from .list_str_model import ListStrModel
 from traitsui.menu import Menu
 
 
-is_qt5 = (QtCore.__version_info__[0] >= 5)
-
-#-------------------------------------------------------------------------
-#  '_ListStrEditor' class:
-#-------------------------------------------------------------------------
-
-
 class _ListStrEditor(Editor):
     """ Traits UI editor for editing lists of strings.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     # The list view control associated with the editor:
-    list_view = Any
+    list_view = Any()
 
-    # The list model associated the editor:
+    #: The list model associated the editor:
     model = Instance(ListStrModel)
 
-    # The title of the editor:
-    title = Str
+    #: The title of the editor:
+    title = Str()
 
-    # The current set of selected items (which one is used depends upon the
-    # initial state of the editor factory 'multi_select' trait):
-    selected = Any
-    multi_selected = List
+    #: The current set of selected items (which one is used depends upon the
+    #: initial state of the editor factory 'multi_select' trait):
+    selected = Any()
+    multi_selected = List()
 
-    # The current set of selected item indices (which one is used depends upon
-    # the initial state of the editor factory 'multi_select' trait):
+    #: The current set of selected item indices (which one is used depends upon
+    #: the initial state of the editor factory 'multi_select' trait):
     selected_index = Int(-1)
     multi_selected_indices = List(Int)
 
-    # The most recently actived item and its index.
-    # Always trigger change notification.
+    #: The most recently actived item and its index.
+    #: Always trigger change notification.
     activated = Any(comparison_mode=NO_COMPARE)
     activated_index = Int(comparison_mode=NO_COMPARE)
 
-    # The most recently right_clicked item and its index:
-    right_clicked = Event
-    right_clicked_index = Event
+    #: The most recently right_clicked item and its index:
+    right_clicked = Event()
+    right_clicked_index = Event()
 
-    # Is the list editor scrollable? This value overrides the default.
+    #: Is the list editor scrollable? This value overrides the default.
     scrollable = True
 
-    # Should the selected item be edited after rebuilding the editor list:
+    #: Should the selected item be edited after rebuilding the editor list:
     edit = Bool(False)
 
-    # The adapter from list items to editor values:
+    #: The adapter from list items to editor values:
     adapter = Instance(ListStrAdapter)
 
-    # Dictionary mapping image names to QIcons
+    #: Dictionary mapping image names to QIcons
     images = Any({})
 
-    # Dictionary mapping ImageResource objects to QIcons
+    #: Dictionary mapping ImageResource objects to QIcons
     image_resources = Any({})
 
-    # The current number of item currently in the list:
-    item_count = Property
+    #: The current number of item currently in the list:
+    item_count = Property()
 
-    # The current search string:
-    search = Str
+    #: The current search string:
+    search = Str()
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Editor interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -112,7 +104,7 @@ class _ListStrEditor(Editor):
 
         # Set up the adapter to use:
         self.adapter = factory.adapter
-        self.sync_value(factory.adapter_name, 'adapter', 'from')
+        self.sync_value(factory.adapter_name, "adapter", "from")
 
         # Create the list model and accompanying controls:
         self.model = ListStrModel(editor=self)
@@ -124,6 +116,7 @@ class _ListStrEditor(Editor):
 
         if factory.title or factory.title_name:
             header_view = QtGui.QHeaderView(QtCore.Qt.Horizontal, self.control)
+            self._header_view = header_view
             header_view.setModel(self.model)
             header_view.setMaximumHeight(header_view.sizeHint().height())
             if is_qt5:
@@ -131,6 +124,8 @@ class _ListStrEditor(Editor):
             else:
                 header_view.setResizeMode(QtGui.QHeaderView.Stretch)
             layout.addWidget(header_view)
+        else:
+            self._header_view = None
 
         self.list_view = _ListView(self)
         layout.addWidget(self.list_view)
@@ -147,40 +142,46 @@ class _ListStrEditor(Editor):
 
         # Initialize the editor title:
         self.title = factory.title
-        self.sync_value(factory.title_name, 'title', 'from')
+        self.sync_value(factory.title_name, "title", "from")
 
         # Set up the selection listener
         if factory.multi_select:
-            self.sync_value(factory.selected, 'multi_selected', 'both',
-                            is_list=True)
-            self.sync_value(factory.selected_index, 'multi_selected_indices',
-                            'both', is_list=True)
+            self.sync_value(
+                factory.selected, "multi_selected", "both", is_list=True
+            )
+            self.sync_value(
+                factory.selected_index,
+                "multi_selected_indices",
+                "both",
+                is_list=True,
+            )
         else:
-            self.sync_value(factory.selected, 'selected', 'both')
-            self.sync_value(factory.selected_index, 'selected_index', 'both')
+            self.sync_value(factory.selected, "selected", "both")
+            self.sync_value(factory.selected_index, "selected_index", "both")
 
         # Synchronize other interesting traits as necessary:
-        self.sync_value(factory.activated, 'activated', 'to')
-        self.sync_value(factory.activated_index, 'activated_index', 'to')
+        self.sync_value(factory.activated, "activated", "to")
+        self.sync_value(factory.activated_index, "activated_index", "to")
 
-        self.sync_value(factory.right_clicked, 'right_clicked', 'to')
+        self.sync_value(factory.right_clicked, "right_clicked", "to")
         self.sync_value(
-            factory.right_clicked_index,
-            'right_clicked_index',
-            'to')
+            factory.right_clicked_index, "right_clicked_index", "to"
+        )
 
         # Make sure we listen for 'items' changes as well as complete list
         # replacements:
-        self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + '_items', dispatch='ui')
+        self.context_object.observe(
+            self.update_editor, self.extended_name + ".items", dispatch="ui"
+        )
 
         # Create the mapping from user supplied images to QIcons:
         for image_resource in factory.images:
             self._add_image(image_resource)
 
         # Refresh the editor whenever the adapter changes:
-        self.on_trait_change(
-            self.refresh_editor, 'adapter.+update', dispatch='ui')
+        self.observe(
+            self.refresh_editor, "adapter.+update", dispatch="ui"
+        )
 
         # Set the list control's tooltip:
         self.set_tooltip()
@@ -188,15 +189,27 @@ class _ListStrEditor(Editor):
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
-        self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + '_items', remove=True)
+        self.model.beginResetModel()
+        self.model.endResetModel()
+        self.context_object.observe(
+            self.update_editor,
+            self.extended_name + ".items",
+            remove=True,
+            dispatch="ui"
+        )
 
-        self.on_trait_change(
-            self.refresh_editor, 'adapter.+update', remove=True)
+        self.observe(
+            self.refresh_editor, "adapter.+update", remove=True, dispatch="ui"
+        )
+        if self._header_view is not None:
+            self._header_view.setModel(None)
+            self._header_view = None
 
-        super(Editor, self).dispose()
+        self.list_view._dispose()
 
-    def update_editor(self):
+        super().dispose()
+
+    def update_editor(self, event=None):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
@@ -209,11 +222,11 @@ class _ListStrEditor(Editor):
             else:
                 self._selected_changed(self.selected)
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  ListStrEditor interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    def refresh_editor(self):
+    def refresh_editor(self, event=None):
         """ Requests that the underlying list widget to redraw itself.
         """
         self.list_view.viewport().update()
@@ -255,12 +268,13 @@ class _ListStrEditor(Editor):
         """ Returns whether or not the index is the special 'auto add' item at
             the end of the list.
         """
-        return (self.factory.auto_add and
-                (index >= self.adapter.len(self.object, self.name)))
+        return self.factory.auto_add and (
+            index >= self.adapter.len(self.object, self.name)
+        )
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Private interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
         """ Adds a new image to the image map.
@@ -272,12 +286,12 @@ class _ListStrEditor(Editor):
 
         return image
 
-    #-- Property Implementations ---------------------------------------------
+    # -- Property Implementations ---------------------------------------------
 
     def _get_item_count(self):
-        return (self.model.rowCount(None) - self.factory.auto_add)
+        return self.model.rowCount(None) - self.factory.auto_add
 
-    #-- Trait Event Handlers -------------------------------------------------
+    # -- Trait Event Handlers -------------------------------------------------
 
     def _selected_changed(self, selected):
         """ Handles the editor's 'selected' trait being changed.
@@ -324,7 +338,11 @@ class _ListStrEditor(Editor):
             except ValueError:
                 pass
             else:
-                event = TraitListEvent(0, added, removed)
+                event = TraitListEvent(
+                    index=0,
+                    added=added,
+                    removed=removed
+                )
                 self._multi_selected_indices_items_changed(event)
 
     def _multi_selected_indices_changed(self, selected_indices):
@@ -334,8 +352,10 @@ class _ListStrEditor(Editor):
             smodel = self.list_view.selectionModel()
             smodel.clearSelection()
             for selected_index in selected_indices:
-                smodel.select(self.model.index(selected_index),
-                              QtGui.QItemSelectionModel.Select)
+                smodel.select(
+                    self.model.index(selected_index),
+                    QtGui.QItemSelectionModel.Select,
+                )
             if selected_indices:
                 self.list_view.scrollTo(self.model.index(selected_indices[-1]))
 
@@ -345,13 +365,17 @@ class _ListStrEditor(Editor):
         if not self._no_update:
             smodel = self.list_view.selectionModel()
             for selected_index in event.removed:
-                smodel.select(self.model.index(selected_index),
-                              QtGui.QItemSelectionModel.Deselect)
+                smodel.select(
+                    self.model.index(selected_index),
+                    QtGui.QItemSelectionModel.Deselect,
+                )
             for selected_index in event.added:
-                smodel.select(self.model.index(selected_index),
-                              QtGui.QItemSelectionModel.Select)
+                smodel.select(
+                    self.model.index(selected_index),
+                    QtGui.QItemSelectionModel.Select,
+                )
 
-    #-- List Control Event Handlers ------------------------------------------
+    # -- List Control Event Handlers ------------------------------------------
 
     def _on_activate(self, mi):
         """ Handle a cell being activated.
@@ -359,14 +383,15 @@ class _ListStrEditor(Editor):
         self.activated_index = index = mi.row()
         self.activated = self.adapter.get_item(self.object, self.name, index)
 
-    def _on_context_menu(self, point):
-        """ Handle a context menu request.
+    def _on_mouse_right_click(self, point):
+        """ Handle a mouse right click event
         """
         mi = self.list_view.indexAt(point)
         if mi.isValid():
             self.right_clicked_index = index = mi.row()
             self.right_clicked = self.adapter.get_item(
-                self.object, self.name, index)
+                self.object, self.name, index
+            )
 
     def _on_row_selection(self, added, removed):
         """ Handle the row selection being changed.
@@ -376,8 +401,9 @@ class _ListStrEditor(Editor):
             indices = self.list_view.selectionModel().selectedRows()
             if len(indices):
                 self.selected_index = indices[0].row()
-                self.selected = self.adapter.get_item(self.object, self.name,
-                                                      self.selected_index)
+                self.selected = self.adapter.get_item(
+                    self.object, self.name, self.selected_index
+                )
             else:
                 self.selected_index = -1
                 self.selected = None
@@ -391,9 +417,10 @@ class _ListStrEditor(Editor):
         try:
             indices = self.list_view.selectionModel().selectedRows()
             self.multi_selected_indices = indices = [i.row() for i in indices]
-            self.multi_selected = [self.adapter.get_item(self.object,
-                                                         self.name, i)
-                                   for i in self.multi_selected_indices]
+            self.multi_selected = [
+                self.adapter.get_item(self.object, self.name, i)
+                for i in self.multi_selected_indices
+            ]
         finally:
             self._no_update = False
 
@@ -405,26 +432,29 @@ class _ListStrEditor(Editor):
         if isinstance(menu, str):
             menu = getattr(self.object, menu, None)
 
-        if isinstance(menu, collections.Callable):
+        if isinstance(menu, collections.abc.Callable):
             menu = menu(index)
 
         if menu is not None:
             qmenu = menu.create_menu(self.list_view, self)
 
-            self._menu_context = {'selection': self.object,
-                                  'object': self.object,
-                                  'editor': self,
-                                  'index': index,
-                                  'info': self.ui.info,
-                                  'handler': self.ui.handler}
+            self._menu_context = {
+                "selection": self.object,
+                "object": self.object,
+                "editor": self,
+                "index": index,
+                "info": self.ui.info,
+                "handler": self.ui.handler,
+            }
 
             qmenu.exec_(self.list_view.mapToGlobal(pos))
 
             self._menu_context = None
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Qt widgets that have been configured to behave as expected by Traits UI:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
@@ -446,8 +476,8 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
             painter.save()
             painter.setPen(option.palette.color(QtGui.QPalette.Dark))
             painter.drawLine(
-                option.rect.bottomLeft(),
-                option.rect.bottomRight())
+                option.rect.bottomLeft(), option.rect.bottomRight()
+            )
             painter.restore()
 
 
@@ -488,6 +518,18 @@ class _ListView(QtGui.QListView):
         # Configure context menu behavior
         self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
 
+    def _dispose(self):
+        """ Clean up states in this view.
+        """
+        self.setModel(None)
+
+    def mouseReleaseEvent(self, event):
+        """ Reimplemented to support listening to right clicked item."""
+        if event.button() == QtCore.Qt.RightButton:
+            event.accept()
+            self._editor._on_mouse_right_click(event.pos())
+        super().mouseReleaseEvent(event)
+
     def keyPressEvent(self, event):
         """ Reimplemented to support edit, insert, and delete by keyboard.
         """
@@ -496,9 +538,12 @@ class _ListView(QtGui.QListView):
 
         # Note that setting 'EditKeyPressed' as an edit trigger does not work on
         # most platforms, which is why we do this here.
-        if (event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return) and
-            self.state() != QtGui.QAbstractItemView.EditingState and
-                factory.editable and 'edit' in factory.operations):
+        if (
+            event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
+            and self.state() != QtGui.QAbstractItemView.EditingState
+            and factory.editable
+            and "edit" in factory.operations
+        ):
             if factory.multi_select:
                 indices = editor.multi_selected_indices
                 row = indices[0] if len(indices) == 1 else -1
@@ -509,8 +554,11 @@ class _ListView(QtGui.QListView):
                 event.accept()
                 self.edit(editor.model.index(row))
 
-        elif (event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete) and
-              factory.editable and 'delete' in factory.operations):
+        elif (
+            event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete)
+            and factory.editable
+            and "delete" in factory.operations
+        ):
             event.accept()
 
             if factory.multi_select:
@@ -528,10 +576,14 @@ class _ListView(QtGui.QListView):
                 editor.model.removeRow(row)
                 # Handle the case of deleting the last item in the list.
                 editor.selected_index = min(
-                    row, editor.adapter.len(editor.object, editor.name) - 1)
+                    row, editor.adapter.len(editor.object, editor.name) - 1
+                )
 
-        elif (event.key() == QtCore.Qt.Key_Insert and
-              factory.editable and 'insert' in factory.operations):
+        elif (
+            event.key() == QtCore.Qt.Key_Insert
+            and factory.editable
+            and "insert" in factory.operations
+        ):
             event.accept()
 
             if factory.multi_select:
