@@ -1,50 +1,55 @@
-#-------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   06/22/2009
-#
-#-------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A traits UI editor for editing tabular data (arrays, list of tuples, lists
     of objects, etc).
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
 
 from contextlib import contextmanager
 
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_qt5
 from pyface.image_resource import ImageResource
 from pyface.ui_traits import Image
 
-from traits.api import (Any, Bool, Callable, Event, HasStrictTraits, Instance,
-                        Int, List, NO_COMPARE, Property, TraitListEvent)
+from traits.api import (
+    Any,
+    Bool,
+    Callable,
+    Event,
+    HasStrictTraits,
+    Instance,
+    Int,
+    List,
+    NO_COMPARE,
+    Property,
+    TraitListEvent,
+)
 
 from traitsui.tabular_adapter import TabularAdapter
 from traitsui.helper import compute_column_widths
 from .editor import Editor
 from .tabular_model import TabularModel
-import six
+
+SCROLL_TO_POSITION_HINT_MAP = {
+    "center": QtGui.QTableView.PositionAtCenter,
+    "top": QtGui.QTableView.PositionAtTop,
+    "bottom": QtGui.QTableView.PositionAtBottom,
+    "visible": QtGui.QTableView.EnsureVisible,
+}
 
 
 class HeaderEventFilter(QtCore.QObject):
-
     def __init__(self, editor):
-        super(HeaderEventFilter, self).__init__()
+        super().__init__()
         self.editor = editor
 
     def eventFilter(self, obj, event):
@@ -59,88 +64,88 @@ class TabularEditor(Editor):
         lists of objects, etc).
     """
 
-    #-- Trait Definitions ----------------------------------------------------
+    # -- Trait Definitions ----------------------------------------------------
 
-    # The event fired when a table update is needed:
-    update = Event
+    #: The event fired when a table update is needed:
+    update = Event()
 
-    # The event fired when a simple repaint is needed:
-    refresh = Event
+    #: The event fired when a simple repaint is needed:
+    refresh = Event()
 
-    # The current set of selected items (which one is used depends upon the
-    # initial state of the editor factory 'multi_select' trait):
-    selected = Any
-    multi_selected = List
+    #: The current set of selected items (which one is used depends upon the
+    #: initial state of the editor factory 'multi_select' trait):
+    selected = Any()
+    multi_selected = List()
 
-    # The current set of selected item indices (which one is used depends upon
-    # the initial state of the editor factory 'multi_select' trait):
+    #: The current set of selected item indices (which one is used depends upon
+    #: the initial state of the editor factory 'multi_select' trait):
     selected_row = Int(-1)
     multi_selected_rows = List(Int)
 
-    # The optional extended name of the trait to synchronize the selection
-    # column with:
+    #: The optional extended name of the trait to synchronize the selection
+    #: column with:
     selected_column = Int(-1)
 
-    # The most recently actived item and its index:
+    #: The most recently actived item and its index:
     activated = Any(comparison_mode=NO_COMPARE)
     activated_row = Int(comparison_mode=NO_COMPARE)
 
-    # The most recent left click data:
-    clicked = Instance('TabularEditorEvent')
+    #: The most recent left click data:
+    clicked = Instance("TabularEditorEvent")
 
-    # The most recent left double click data:
-    dclicked = Instance('TabularEditorEvent')
+    #: The most recent left double click data:
+    dclicked = Instance("TabularEditorEvent")
 
-    # The most recent right click data:
-    right_clicked = Instance('TabularEditorEvent')
+    #: The most recent right click data:
+    right_clicked = Instance("TabularEditorEvent")
 
-    # The most recent right double click data:
-    right_dclicked = Instance('TabularEditorEvent')
+    #: The most recent right double click data:
+    right_dclicked = Instance("TabularEditorEvent")
 
-    # The most recent column click data:
-    column_clicked = Instance('TabularEditorEvent')
+    #: The most recent column click data:
+    column_clicked = Instance("TabularEditorEvent")
 
-    # The most recent column click data:
-    column_right_clicked = Instance('TabularEditorEvent')
+    #: The most recent column click data:
+    column_right_clicked = Instance("TabularEditorEvent")
 
-    # The event triggering scrolling.
+    #: The event triggering scrolling.
     scroll_to_row = Event(Int)
 
-    # The event triggering scrolling.
+    #: The event triggering scrolling.
     scroll_to_column = Event(Int)
 
-    # Is the tabular editor scrollable? This value overrides the default.
+    #: Is the tabular editor scrollable? This value overrides the default.
     scrollable = True
 
-    # NIT: This doesn't seem to be used anywhere...can I delete?
-    # # Row index of item to select after rebuilding editor list:
-    # row = Any
+    #: NIT: This doesn't seem to be used anywhere...can I delete?
+    #: # Row index of item to select after rebuilding editor list:
+    #: row = Any()
 
-    # Should the selected item be edited after rebuilding the editor list:
+    #: Should the selected item be edited after rebuilding the editor list:
     edit = Bool(False)
 
-    # The adapter from trait values to editor values:
+    #: The adapter from trait values to editor values:
     adapter = Instance(TabularAdapter)
 
-    # The table model associated with the editor:
+    #: The table model associated with the editor:
     model = Instance(TabularModel)
 
-    # Dictionary mapping image names to QIcons
+    #: Dictionary mapping image names to QIcons
     images = Any({})
 
-    # Dictionary mapping ImageResource objects to QIcons
+    #: Dictionary mapping ImageResource objects to QIcons
     image_resources = Any({})
 
-    # An image being converted:
+    #: An image being converted:
     image = Image
 
     header_event_filter = Any()
 
     widget_factory = Callable(lambda *args, **kwds: _TableView(*args, **kwds))
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Editor interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
@@ -155,16 +160,18 @@ class TabularEditor(Editor):
 
         # Set up the selection listener
         if factory.multi_select:
-            self.sync_value(factory.selected, 'multi_selected', 'both',
-                            is_list=True)
+            self.sync_value(
+                factory.selected, "multi_selected", "both", is_list=True
+            )
             self.sync_value(
                 factory.selected_row,
-                'multi_selected_rows',
-                'both',
-                is_list=True)
+                "multi_selected_rows",
+                "both",
+                is_list=True,
+            )
         else:
-            self.sync_value(factory.selected, 'selected', 'both')
-            self.sync_value(factory.selected_row, 'selected_row', 'both')
+            self.sync_value(factory.selected, "selected", "both")
+            self.sync_value(factory.selected_row, "selected_row", "both")
 
         # Connect to the mode specific selection handler
         if factory.multi_select:
@@ -175,23 +182,24 @@ class TabularEditor(Editor):
         selection_model.selectionChanged.connect(slot)
 
         # Synchronize other interesting traits as necessary:
-        self.sync_value(factory.update, 'update', 'from', is_event=True)
-        self.sync_value(factory.refresh, 'refresh', 'from', is_event=True)
-        self.sync_value(factory.activated, 'activated', 'to')
-        self.sync_value(factory.activated_row, 'activated_row', 'to')
-        self.sync_value(factory.clicked, 'clicked', 'to')
-        self.sync_value(factory.dclicked, 'dclicked', 'to')
-        self.sync_value(factory.right_clicked, 'right_clicked', 'to')
-        self.sync_value(factory.right_dclicked, 'right_dclicked', 'to')
-        self.sync_value(factory.column_clicked, 'column_clicked', 'to')
+        self.sync_value(factory.update, "update", "from", is_event=True)
+        self.sync_value(factory.refresh, "refresh", "from", is_event=True)
+        self.sync_value(factory.activated, "activated", "to")
+        self.sync_value(factory.activated_row, "activated_row", "to")
+        self.sync_value(factory.clicked, "clicked", "to")
+        self.sync_value(factory.dclicked, "dclicked", "to")
+        self.sync_value(factory.right_clicked, "right_clicked", "to")
+        self.sync_value(factory.right_dclicked, "right_dclicked", "to")
+        self.sync_value(factory.column_clicked, "column_clicked", "to")
         self.sync_value(
-            factory.column_right_clicked,
-            'column_right_clicked',
-            'to')
-        self.sync_value(factory.scroll_to_row, 'scroll_to_row', 'from',
-                        is_event=True)
-        self.sync_value(factory.scroll_to_column, 'scroll_to_column', 'from',
-                        is_event=True)
+            factory.column_right_clicked, "column_right_clicked", "to"
+        )
+        self.sync_value(
+            factory.scroll_to_row, "scroll_to_row", "from", is_event=True
+        )
+        self.sync_value(
+            factory.scroll_to_column, "scroll_to_column", "from", is_event=True
+        )
 
         # Connect other signals as necessary
         control.activated.connect(self._on_activate)
@@ -199,7 +207,8 @@ class TabularEditor(Editor):
         control.clicked.connect(self._on_right_click)
         control.doubleClicked.connect(self._on_dclick)
         control.horizontalHeader().sectionClicked.connect(
-            self._on_column_click)
+            self._on_column_click
+        )
 
         control.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
         control.customContextMenuRequested.connect(self._on_context_menu)
@@ -211,7 +220,10 @@ class TabularEditor(Editor):
         # replacements:
         try:
             self.context_object.on_trait_change(
-                self.update_editor, self.extended_name + '_items', dispatch='ui')
+                self.update_editor,
+                self.extended_name + "_items",
+                dispatch="ui",
+            )
         except:
             pass
 
@@ -219,39 +231,49 @@ class TabularEditor(Editor):
         # appropriate listeners:
         if factory.auto_update:
             self.context_object.on_trait_change(
-                self.refresh_editor, self.extended_name + '.-', dispatch='ui')
+                self.refresh_editor, self.extended_name + ".-", dispatch="ui"
+            )
 
         # Create the mapping from user supplied images to QImages:
         for image_resource in factory.images:
             self._add_image(image_resource)
 
         # Refresh the editor whenever the adapter changes:
-        self.on_trait_change(self.refresh_editor, 'adapter.+update',
-                             dispatch='ui')
+        self.on_trait_change(
+            self.refresh_editor, "adapter.+update", dispatch="ui"
+        )
 
         # Rebuild the editor columns and headers whenever the adapter's
         # 'columns' changes:
-        self.on_trait_change(self.update_editor, 'adapter.columns',
-                             dispatch='ui')
+        self.on_trait_change(
+            self._adapter_columns_updated, "adapter.columns", dispatch="ui"
+        )
 
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
+        self.model.beginResetModel()
+        self.model.endResetModel()
+
         self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + '_items', remove=True)
+            self.update_editor, self.extended_name + "_items", remove=True
+        )
 
         if self.factory.auto_update:
             self.context_object.on_trait_change(
-                self.refresh_editor, self.extended_name + '.-', remove=True)
+                self.refresh_editor, self.extended_name + ".-", remove=True
+            )
 
-        self.on_trait_change(self.refresh_editor, 'adapter.+update',
-                             remove=True)
-        self.on_trait_change(self.update_editor, 'adapter.columns',
-                             remove=True)
+        self.on_trait_change(
+            self.refresh_editor, "adapter.+update", remove=True
+        )
+        self.on_trait_change(
+            self._adapter_columns_updated, "adapter.columns", remove=True
+        )
 
         self.adapter.cleanup()
 
-        super(TabularEditor, self).dispose()
+        super().dispose()
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -265,9 +287,9 @@ class TabularEditor(Editor):
             else:
                 self._selected_changed(self.selected)
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  TabularEditor interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def refresh_editor(self):
         """ Requests the table view to redraw itself.
@@ -295,15 +317,15 @@ class TabularEditor(Editor):
         finally:
             self._no_notify = old
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  UI preference save/restore interface:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def restore_prefs(self, prefs):
         """ Restores any saved user preference information associated with the
             editor.
         """
-        cws = prefs.get('cached_widths')
+        cws = prefs.get("cached_widths")
         num_columns = len(self.adapter.columns)
         if cws is not None and num_columns == len(cws):
             for column in range(num_columns):
@@ -312,13 +334,15 @@ class TabularEditor(Editor):
     def save_prefs(self):
         """ Returns any user preference information associated with the editor.
         """
-        widths = [self.control.columnWidth(column)
-                  for column in range(len(self.adapter.columns))]
-        return {'cached_widths': widths}
+        widths = [
+            self.control.columnWidth(column)
+            for column in range(len(self.adapter.columns))
+        ]
+        return {"cached_widths": widths}
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Private methods:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
         """ Adds a new image to the image map.
@@ -333,7 +357,7 @@ class TabularEditor(Editor):
     def _get_image(self, image):
         """ Converts a user specified image to a QIcon.
         """
-        if isinstance(image, six.string_types):
+        if isinstance(image, str):
             self.image = image
             image = self.image
 
@@ -349,11 +373,12 @@ class TabularEditor(Editor):
         """ Generate a TabularEditorEvent event for a specified model index and
             editor trait name.
         """
-        event = TabularEditorEvent(editor=self, row=index.row(),
-                                   column=index.column())
+        event = TabularEditorEvent(
+            editor=self, row=index.row(), column=index.column()
+        )
         setattr(self, trait, event)
 
-    #-- Trait Event Handlers -------------------------------------------------
+    # -- Trait Event Handlers -------------------------------------------------
 
     def _clicked_changed(self):
         """ When mouse is clicked on a specific cell, update the selected
@@ -367,7 +392,20 @@ class TabularEditor(Editor):
         """ When column is clicked, update selected column first
         """
         if not self.factory.multi_select:
-            self.selected_column = self.clicked.column
+            self.selected_column = self.column_clicked.column
+
+    def _adapter_columns_updated(self):
+        """ Update the view when the adapter columns trait changes.
+        Note that this change handler is added after the UI is instantiated,
+        and removed when the UI is disposed.
+        """
+        # Invalidate internal state of the view related to the columns
+        n_columns = len(self.adapter.columns)
+        if (self.control is not None
+                and self.control._user_widths is not None
+                and len(self.control._user_widths) != n_columns):
+            self.control._user_widths = None
+        self.update_editor()
 
     def _update_changed(self):
         self.update_editor()
@@ -384,6 +422,7 @@ class TabularEditor(Editor):
                     selected_row = self.value.index(new)
                 except Exception:
                     from traitsui.api import raise_to_debug
+
                     raise_to_debug()
                 else:
                     self._selected_row_changed(selected_row)
@@ -396,11 +435,10 @@ class TabularEditor(Editor):
             else:
                 smodel.select(
                     self.model.index(
-                        selected_row,
-                        max(self.selected_column, 0)
+                        selected_row, max(self.selected_column, 0)
                     ),
-                    QtGui.QItemSelectionModel.ClearAndSelect |
-                    QtGui.QItemSelectionModel.Rows
+                    QtGui.QItemSelectionModel.ClearAndSelect
+                    | QtGui.QItemSelectionModel.Rows,
                 )
                 # Once selected, scroll to the row
                 self.scroll_to_row = selected_row
@@ -423,7 +461,11 @@ class TabularEditor(Editor):
         except:
             pass
         else:
-            list_event = TraitListEvent(0, added, removed)
+            list_event = TraitListEvent(
+                index=0,
+                added=added,
+                removed=removed
+            )
             self._multi_selected_rows_items_changed(list_event)
 
     def _multi_selected_rows_changed(self, selected_rows):
@@ -432,25 +474,30 @@ class TabularEditor(Editor):
             selection = QtGui.QItemSelection()
             for row in selected_rows:
                 selection.select(
-                    self.model.index(
-                        row, 0), self.model.index(
-                        row, 0))
+                    self.model.index(row, 0), self.model.index(row, 0)
+                )
             smodel.clearSelection()
-            smodel.select(selection,
-                          QtGui.QItemSelectionModel.Select |
-                          QtGui.QItemSelectionModel.Rows)
+            smodel.select(
+                selection,
+                QtGui.QItemSelectionModel.Select
+                | QtGui.QItemSelectionModel.Rows,
+            )
 
     def _multi_selected_rows_items_changed(self, event):
         if not self._no_update:
             smodel = self.control.selectionModel()
             for row in event.removed:
-                smodel.select(self.model.index(row, 0),
-                            QtGui.QItemSelectionModel.Deselect |
-                            QtGui.QItemSelectionModel.Rows)
+                smodel.select(
+                    self.model.index(row, 0),
+                    QtGui.QItemSelectionModel.Deselect
+                    | QtGui.QItemSelectionModel.Rows,
+                )
             for row in event.added:
-                smodel.select(self.model.index(row, 0),
-                            QtGui.QItemSelectionModel.Select |
-                            QtGui.QItemSelectionModel.Rows)
+                smodel.select(
+                    self.model.index(row, 0),
+                    QtGui.QItemSelectionModel.Select
+                    | QtGui.QItemSelectionModel.Rows,
+                )
 
     def _selected_column_changed(self, selected_column):
         if not self._no_update:
@@ -458,43 +505,37 @@ class TabularEditor(Editor):
             if selected_column >= 0:
                 smodel.select(
                     self.model.index(
-                        max(self.selected_row, 0),
-                        selected_column
+                        max(self.selected_row, 0), selected_column
                     ),
-                    QtGui.QItemSelectionModel.ClearAndSelect |
-                    QtGui.QItemSelectionModel.Rows
+                    QtGui.QItemSelectionModel.ClearAndSelect
+                    | QtGui.QItemSelectionModel.Rows,
                 )
                 # Once selected, scroll to the column
                 self.scroll_to_column = selected_column
 
-    scroll_to_row_hint_map = {
-        'center': QtGui.QTableView.PositionAtCenter,
-        'top': QtGui.QTableView.PositionAtTop,
-        'bottom': QtGui.QTableView.PositionAtBottom,
-        'visible': QtGui.QTableView.EnsureVisible,
-    }
-
     def _scroll_to_row_changed(self, row):
         """ Scroll to the given row.
         """
-        scroll_hint = self.scroll_to_row_hint_map.get(
-            self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
+        scroll_hint = SCROLL_TO_POSITION_HINT_MAP.get(
+            self.factory.scroll_to_position_hint,
+            self.control.EnsureVisible
+        )
         self.control.scrollTo(
-            self.model.index(row, max(self.selected_column, 0)),
-            scroll_hint
+            self.model.index(row, max(self.selected_column, 0)), scroll_hint
         )
 
     def _scroll_to_column_changed(self, column):
         """ Scroll to the given column.
         """
-        scroll_hint = self.scroll_to_row_hint_map.get(
-            self.factory.scroll_to_row_hint, self.control.PositionAtCenter)
+        scroll_hint = SCROLL_TO_POSITION_HINT_MAP.get(
+            self.factory.scroll_to_position_hint,
+            self.control.EnsureVisible
+        )
         self.control.scrollTo(
-            self.model.index(max(self.selected_row, 0), column),
-            scroll_hint
+            self.model.index(max(self.selected_row, 0), column), scroll_hint
         )
 
-    #-- Table Control Event Handlers -----------------------------------------
+    # -- Table Control Event Handlers -----------------------------------------
 
     def _on_activate(self, index):
         """ Handle a cell being activated.
@@ -505,24 +546,24 @@ class TabularEditor(Editor):
     def _on_click(self, index):
         """ Handle a cell being clicked.
         """
-        self._mouse_click(index, 'clicked')
+        self._mouse_click(index, "clicked")
 
     def _on_dclick(self, index):
         """ Handle a cell being double clicked.
         """
-        self._mouse_click(index, 'dclicked')
+        self._mouse_click(index, "dclicked")
 
     def _on_column_click(self, column):
         event = TabularEditorEvent(editor=self, row=0, column=column)
-        setattr(self, 'column_clicked', event)
+        setattr(self, "column_clicked", event)
 
     def _on_right_click(self, column):
         event = TabularEditorEvent(editor=self, row=0, column=column)
-        setattr(self, 'right_clicked', event)
+        setattr(self, "right_clicked", event)
 
     def _on_column_right_click(self, column):
         event = TabularEditorEvent(editor=self, row=0, column=column)
-        setattr(self, 'column_right_clicked', event)
+        setattr(self, "column_right_clicked", event)
 
     def _on_row_selection(self, added, removed):
         """ Handle the row selection being changed.
@@ -532,8 +573,9 @@ class TabularEditor(Editor):
             indexes = self.control.selectionModel().selectedRows()
             if len(indexes):
                 self.selected_row = indexes[0].row()
-                self.selected = self.adapter.get_item(self.object, self.name,
-                                                      self.selected_row)
+                self.selected = self.adapter.get_item(
+                    self.object, self.name, self.selected_row
+                )
             else:
                 self.selected_row = -1
                 self.selected = None
@@ -551,31 +593,31 @@ class TabularEditor(Editor):
             for index in indexes:
                 row = index.row()
                 selected_rows.append(row)
-                selected.append(self.adapter.get_item(self.object, self.name,
-                                                      row))
+                selected.append(
+                    self.adapter.get_item(self.object, self.name, row)
+                )
             self.multi_selected_rows = selected_rows
             self.multi_selected = selected
         finally:
             self._no_update = False
 
     def _on_context_menu(self, pos):
-        column, row = self.control.columnAt(
-            pos.x()), self.control.rowAt(
-            pos.y())
+        column, row = (
+            self.control.columnAt(pos.x()),
+            self.control.rowAt(pos.y()),
+        )
         menu = self.adapter.get_menu(self.object, self.name, row, column)
         if menu:
             self._menu_context = {
-                'selection': self.object,
-                'object': self.object,
-                'editor': self,
-                'column': column,
-                'row': row,
-                'item': self.adapter.get_item(
-                    self.object,
-                    self.name,
-                    row),
-                'info': self.ui.info,
-                'handler': self.ui.handler}
+                "selection": self.object,
+                "object": self.object,
+                "editor": self,
+                "column": column,
+                "row": row,
+                "item": self.adapter.get_item(self.object, self.name, row),
+                "info": self.ui.info,
+                "handler": self.ui.handler,
+            }
             qmenu = menu.create_menu(self.control, self)
             qmenu.exec_(self.control.mapToGlobal(pos))
             self._menu_context = None
@@ -585,49 +627,47 @@ class TabularEditor(Editor):
         menu = self.adapter.get_column_menu(self.object, self.name, -1, column)
         if menu:
             self._menu_context = {
-                'selection': self.object,
-                'object': self.object,
-                'editor': self,
-                'column': column,
-                'info': self.ui.info,
-                'handler': self.ui.handler}
+                "selection": self.object,
+                "object": self.object,
+                "editor": self,
+                "column": column,
+                "info": self.ui.info,
+                "handler": self.ui.handler,
+            }
             qmenu = menu.create_menu(self.control, self)
             qmenu.exec_(self.control.mapToGlobal(pos))
             self._menu_context = None
         else:
-            #If no menu is defined on the adapter, just trigger a click event.
+            # If no menu is defined on the adapter, just trigger a click event.
             self._on_column_right_click(column)
 
 
-#-------------------------------------------------------------------------
-#  'TabularEditorEvent' class:
-#-------------------------------------------------------------------------
-
 class TabularEditorEvent(HasStrictTraits):
 
     # The index of the row:
-    row = Int
+    row = Int()
 
     # The id of the column (either a string or an integer):
-    column = Any
+    column = Any()
 
     # The row item:
-    item = Property
+    item = Property()
 
-    #-- Private Traits -------------------------------------------------------
+    # -- Private Traits -------------------------------------------------------
 
     # The editor the event is associated with:
     editor = Instance(TabularEditor)
 
-    #-- Property Implementations ---------------------------------------------
+    # -- Property Implementations ---------------------------------------------
 
     def _get_item(self):
         editor = self.editor
         return editor.adapter.get_item(editor.object, editor.name, self.row)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #  Qt widgets that have been configured to behave as expected by Traits UI:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
@@ -650,15 +690,15 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
         painter.save()
 
         # FIXME: 'styleHint' is returning bogus (negative) values. Why?
-        #style = QtGui.QApplication.instance().style()
-        #color = style.styleHint(QtGui.QStyle.SH_Table_GridLineColor, option)
-        #painter.setPen(QtGui.QColor(color))
+        # style = QtGui.QApplication.instance().style()
+        # color = style.styleHint(QtGui.QStyle.SH_Table_GridLineColor, option)
+        # painter.setPen(QtGui.QColor(color))
         painter.setPen(option.palette.color(QtGui.QPalette.Dark))
 
         if self._horizontal_lines:
             painter.drawLine(
-                option.rect.bottomLeft(),
-                option.rect.bottomRight())
+                option.rect.bottomLeft(), option.rect.bottomRight()
+            )
         if self._vertical_lines:
             painter.drawLine(option.rect.topRight(), option.rect.bottomRight())
 
@@ -688,7 +728,12 @@ class _TableView(QtGui.QTableView):
             vheader.hide()
 
         if factory.show_row_titles and factory.auto_resize_rows:
-            vheader.setResizeMode(QtGui.QHeaderView.ResizeToContents)
+            if is_qt5:
+                vheader.setSectionResizeMode(
+                    QtGui.QHeaderView.ResizeToContents
+                )
+            else:
+                vheader.setResizeMode(QtGui.QHeaderView.ResizeToContents)
         else:
             # Set a default height for rows. Although setting the resize mode to
             # ResizeToContents would provide the best sizes, this is far too
@@ -704,8 +749,8 @@ class _TableView(QtGui.QTableView):
                 font = editor.adapter.get_font(editor.object, editor.name, 0)
             if font is not None:
                 size = max(
-                    size, QtGui.QFontMetrics(
-                        QtGui.QFont(font)).height())
+                    size, QtGui.QFontMetrics(QtGui.QFont(font)).height()
+                )
             vheader.setDefaultSectionSize(size)
 
         # Configure the column headings.
@@ -747,9 +792,12 @@ class _TableView(QtGui.QTableView):
 
         # Note that setting 'EditKeyPressed' as an edit trigger does not work on
         # most platforms, which is why we do this here.
-        if (event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return) and
-            self.state() != QtGui.QAbstractItemView.EditingState and
-                factory.editable and 'edit' in factory.operations):
+        if (
+            event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
+            and self.state() != QtGui.QAbstractItemView.EditingState
+            and factory.editable
+            and "edit" in factory.operations
+        ):
             if factory.multi_select:
                 rows = editor.multi_selected_rows
                 row = rows[0] if len(rows) == 1 else -1
@@ -760,8 +808,11 @@ class _TableView(QtGui.QTableView):
                 event.accept()
                 self.edit(editor.model.index(row, 0))
 
-        elif (event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete) and
-              factory.editable and 'delete' in factory.operations):
+        elif (
+            event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete)
+            and factory.editable
+            and "delete" in factory.operations
+        ):
             event.accept()
 
             if factory.multi_select:
@@ -770,8 +821,11 @@ class _TableView(QtGui.QTableView):
             elif editor.selected_row != -1:
                 editor.model.removeRow(editor.selected_row)
 
-        elif (event.key() == QtCore.Qt.Key_Insert and
-              factory.editable and 'insert' in factory.operations):
+        elif (
+            event.key() == QtCore.Qt.Key_Insert
+            and factory.editable
+            and "insert" in factory.operations
+        ):
             event.accept()
 
             if factory.multi_select:
@@ -805,7 +859,7 @@ class _TableView(QtGui.QTableView):
             space be known, we have to wait until the UI that contains this
             table gives it its initial size.
         """
-        super(_TableView, self).resizeEvent(event)
+        super().resizeEvent(event)
 
         parent = self.parent()
         if (
@@ -823,7 +877,7 @@ class _TableView(QtGui.QTableView):
         editor = self._editor
         if editor.factory.auto_resize:
             # Use the default implementation.
-            return super(_TableView, self).sizeHintForColumn(column)
+            return super().sizeHintForColumn(column)
 
         width = editor.adapter.get_width(editor.object, editor.name, column)
         if width > 1:
@@ -841,7 +895,7 @@ class _TableView(QtGui.QTableView):
         adapter = editor.adapter
         if editor.factory.auto_resize:
             # Use the default implementation.
-            return super(_TableView, self).resizeColumnsToContents()
+            return super().resizeColumnsToContents()
 
         available_space = self.viewport().width()
         requested = []
@@ -869,7 +923,8 @@ class _TableView(QtGui.QTableView):
             if self._user_widths is None:
                 self._user_widths = [None] * len(self._editor.adapter.columns)
             self._user_widths[index] = new
-            if not self._editor.factory.auto_resize:
+            if (self._editor.factory is not None
+                    and not self._editor.factory.auto_resize):
                 self.resizeColumnsToContents()
 
     @contextmanager
