@@ -1,51 +1,39 @@
-#-------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   06/22/2009
-#
-#-------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the table model used by the tabular editor.
 """
 
-#-------------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------------
+
+
+import logging
 
 from pyface.qt import QtCore, QtGui
 
 from traitsui.ui_traits import SequenceTypes
-
 from .clipboard import PyMimeData
 
-#-------------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------------
 
 # Mapping for trait alignment values to qt4 alignment values:
 alignment_map = {
-    'left':    QtCore.Qt.AlignLeft,
-    'right':   QtCore.Qt.AlignRight,
-    'center':  QtCore.Qt.AlignHCenter,
-    'justify': QtCore.Qt.AlignJustify
+    "left": QtCore.Qt.AlignLeft,
+    "right": QtCore.Qt.AlignRight,
+    "center": QtCore.Qt.AlignHCenter,
+    "justify": QtCore.Qt.AlignJustify,
 }
 
 # MIME type for internal table drag/drop operations
-tabular_mime_type = 'traits-ui-tabular-editor'
+tabular_mime_type = "traits-ui-tabular-editor"
+
+logger = logging.getLogger(__name__)
 
-#-------------------------------------------------------------------------------
-#  'TabularModel' class:
-#-------------------------------------------------------------------------------
 
 class TabularModel(QtCore.QAbstractTableModel):
     """ The model for tabular data."""
@@ -57,9 +45,9 @@ class TabularModel(QtCore.QAbstractTableModel):
 
         self._editor = editor
 
-    #---------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  QAbstractItemModel interface:
-    #---------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def data(self, mi, role):
         """ Reimplemented to return the data.
@@ -73,7 +61,9 @@ class TabularModel(QtCore.QAbstractTableModel):
             return adapter.get_text(obj, name, row, column)
 
         elif role == QtCore.Qt.DecorationRole:
-            image = editor._get_image(adapter.get_image(obj, name, row, column))
+            image = editor._get_image(
+                adapter.get_image(obj, name, row, column)
+            )
             if image is not None:
                 return image
 
@@ -123,8 +113,7 @@ class TabularModel(QtCore.QAbstractTableModel):
         row, column = mi.row(), mi.column()
 
         editor.adapter.set_text(obj, name, row, column, value)
-        signal = QtCore.SIGNAL('dataChanged(QModelIndex,QModelIndex)')
-        self.emit(signal, mi, mi)
+        self.dataChanged.emit(mi, mi)
         return True
 
     def flags(self, mi):
@@ -143,20 +132,30 @@ class TabularModel(QtCore.QAbstractTableModel):
 
         # If the adapter defines get_can_edit_cell(), use it to determine
         # editability over the row-wise get_can_edit().
-        if (editor.factory.editable and 'edit' in editor.factory.operations and
-                hasattr(editor.adapter, 'get_can_edit_cell')):
-            if editor.adapter.get_can_edit_cell(editor.object, editor.name,
-                                                row, column):
+        if (
+            editor.factory.editable
+            and "edit" in editor.factory.operations
+            and hasattr(editor.adapter, "get_can_edit_cell")
+        ):
+            if editor.adapter.get_can_edit_cell(
+                editor.object, editor.name, row, column
+            ):
                 flags |= QtCore.Qt.ItemIsEditable
-        elif (editor.factory.editable and 'edit' in editor.factory.operations and
-                editor.adapter.get_can_edit(editor.object, editor.name, row)):
+        elif (
+            editor.factory.editable
+            and "edit" in editor.factory.operations
+            and editor.adapter.get_can_edit(editor.object, editor.name, row)
+        ):
             flags |= QtCore.Qt.ItemIsEditable
 
-        if editor.adapter.get_drag(editor.object, editor.name, row) is not None:
+        if (
+            editor.adapter.get_drag(editor.object, editor.name, row)
+            is not None
+        ):
             flags |= QtCore.Qt.ItemIsDragEnabled
 
         if editor.factory.editable:
-            flags |=  QtCore.Qt.ItemIsDropEnabled
+            flags |= QtCore.Qt.ItemIsDropEnabled
 
         return flags
 
@@ -198,7 +197,9 @@ class TabularModel(QtCore.QAbstractTableModel):
         if obj is None:
             obj = adapter.get_default_value(editor.object, editor.name)
         self.beginInsertRows(parent, row, row)
-        editor.callx(editor.adapter.insert, editor.object, editor.name, row, obj)
+        editor.callx(
+            editor.adapter.insert, editor.object, editor.name, row, obj
+        )
         self.endInsertRows()
         return True
 
@@ -209,9 +210,11 @@ class TabularModel(QtCore.QAbstractTableModel):
         adapter = editor.adapter
 
         self.beginInsertRows(parent, row, row + count - 1)
-        for i in xrange(count):
+        for i in range(count):
             value = adapter.get_default_value(editor.object, editor.name)
-            editor.callx(adapter.insert, editor.object, editor.name, row, value)
+            editor.callx(
+                adapter.insert, editor.object, editor.name, row, value
+            )
         self.endInsertRows()
         return True
 
@@ -222,14 +225,14 @@ class TabularModel(QtCore.QAbstractTableModel):
         editor = self._editor
         adapter = editor.adapter
         self.beginRemoveRows(parent, row, row + count - 1)
-        for i in xrange(count):
+        for i in range(count):
             editor.callx(adapter.delete, editor.object, editor.name, row)
         self.endRemoveRows()
         n = self.rowCount(None)
         if not editor.factory.multi_select:
-            editor.selected_row = row if row < n else row-1
+            editor.selected_row = row if row < n else row - 1
         else:
-            #FIXME: what should the selection be?
+            # FIXME: what should the selection be?
             editor.multi_selected_rows = []
         return True
 
@@ -237,21 +240,27 @@ class TabularModel(QtCore.QAbstractTableModel):
         """ Reimplemented to expose our internal MIME type for drag and drop
             operations.
         """
-        return [ tabular_mime_type, PyMimeData.MIME_TYPE,
-                PyMimeData.NOPICKLE_MIME_TYPE ]
+        return [
+            tabular_mime_type,
+            PyMimeData.MIME_TYPE,
+            PyMimeData.NOPICKLE_MIME_TYPE,
+        ]
 
     def mimeData(self, indexes):
         """ Reimplemented to generate MIME data containing the rows of the
             current selection.
         """
-        rows = sorted(set([ index.row() for index in indexes ]))
-        items = [self._editor.adapter.get_drag(
-                self._editor.object, self._editor.name, row)
-                for row in rows]
+        rows = sorted({index.row() for index in indexes})
+        items = [
+            self._editor.adapter.get_drag(
+                self._editor.object, self._editor.name, row
+            )
+            for row in rows
+        ]
         mime_data = PyMimeData.coerce(items)
-        data = QtCore.QByteArray(str(id(self)))
+        data = QtCore.QByteArray(str(id(self)).encode("utf8"))
         for row in rows:
-            data.append(' %i' % row)
+            data.append((" %i" % row).encode("utf8"))
         mime_data.setData(tabular_mime_type, data)
         return mime_data
 
@@ -261,15 +270,26 @@ class TabularModel(QtCore.QAbstractTableModel):
         if action == QtCore.Qt.IgnoreAction:
             return False
 
+        # If dropped directly onto the parent, both row and column are -1.
+        # See https://doc.qt.io/qt-5/qabstractitemmodel.html#dropMimeData
+        # When dropped below the list, the "parent" is invalid.
+        if row == -1:
+            if parent.isValid():
+                row = parent.row()
+            else:
+                row = max(0, self.rowCount(None) - 1)
+
         # this is a drag from a tabular model
         data = mime_data.data(tabular_mime_type)
         if not data.isNull() and action == QtCore.Qt.MoveAction:
-            id_and_rows = map(int, str(data).split(' '))
+            id_and_rows = [
+                int(s) for s in data.data().decode("utf8").split(" ")
+            ]
             table_id = id_and_rows[0]
             # is it from ourself?
             if table_id == id(self):
                 current_rows = id_and_rows[1:]
-                self.moveRows(current_rows, parent.row())
+                self.moveRows(current_rows, row)
                 return True
 
         # this is an external drag
@@ -281,14 +301,9 @@ class TabularModel(QtCore.QAbstractTableModel):
             object = editor.object
             name = editor.name
             adapter = editor.adapter
-            if row == -1 and parent.isValid():
-                # find correct row number
-                row = parent.row()
-            if row == -1 and adapter.len(object, name) == 0:
-                # if empty list, target is after end of list
-                row = 0
-            if all(adapter.get_can_drop(object, name, row, item)
-                                    for item in data):
+            if all(
+                adapter.get_can_drop(object, name, row, item) for item in data
+            ):
                 for item in reversed(data):
                     self.dropItem(item, row)
                 return True
@@ -297,11 +312,11 @@ class TabularModel(QtCore.QAbstractTableModel):
     def supportedDropActions(self):
         """ Reimplemented to allow items to be moved.
         """
-        return QtCore.Qt.MoveAction
+        return QtCore.Qt.MoveAction | QtCore.Qt.CopyAction
 
-    #---------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  TabularModel interface:
-    #---------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
     def dropItem(self, item, row):
         """ Handle a Python object being dropped onto a row """
@@ -311,7 +326,7 @@ class TabularModel(QtCore.QAbstractTableModel):
         adapter = editor.adapter
         destination = adapter.get_dropped(object, name, row, item)
 
-        if destination == 'after':
+        if destination == "after":
             row += 1
 
         adapter.insert(object, name, row, item)
@@ -327,6 +342,14 @@ class TabularModel(QtCore.QAbstractTableModel):
         """
         editor = self._editor
 
+        if new_row == -1:
+            # row should be nonnegative and less than the row count for this
+            # model. See ``QAbstractItemModel.checkIndex``` for Qt 5.11+
+            # This is a last resort to prevent segmentation faults.
+            logger.debug(
+                "Received invalid row %d. Adjusting to the last row.", new_row)
+            new_row = max(0, self.rowCount(None) - 1)
+
         # Sort rows in descending order so they can be removed without
         # invalidating the indices.
         current_rows.sort()
@@ -352,8 +375,10 @@ class TabularModel(QtCore.QAbstractTableModel):
 
         # Update the selection for the new location.
         if editor.factory.multi_select:
-            editor.setx(multi_selected = objects)
-            editor.multi_selected_rows = range(new_row, new_row + len(objects))
+            editor.setx(multi_selected=objects)
+            editor.multi_selected_rows = list(
+                range(new_row, new_row + len(objects))
+            )
         else:
-            editor.setx(selected = objects[0])
+            editor.setx(selected=objects[0])
             editor.selected_row = new_row
