@@ -1,19 +1,12 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2006, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   06/25/2006
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the various editors for a drag-and-drop editor,
     for the wxPython user interface toolkit. A drag-and-drop editor represents
@@ -22,29 +15,20 @@
     target.
 """
 
-#-------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------
 
-from __future__ import absolute_import
 import wx
 import numpy
 
-from six.moves.cPickle \
-    import load
+from pickle import load
 
-from traits.api \
-    import Bool
+from traits.api import Bool
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.dnd_editor file.
-from traitsui.editors.dnd_editor \
-    import ToolkitEditorFactory
+from pyface.wx.drag_and_drop import (
+    PythonDropSource,
+    PythonDropTarget,
+    clipboard,
+)
 
-from pyface.wx.drag_and_drop \
-    import PythonDropSource, PythonDropTarget, clipboard
-import six
 
 try:
     from apptools.io import File
@@ -56,31 +40,26 @@ try:
 except ImportError:
     Binding = None
 
-from pyface.image_resource \
-    import ImageResource
+from pyface.image_resource import ImageResource
 
-from .editor \
-    import Editor
+from .editor import Editor
 
-#-------------------------------------------------------------------------
-#  Constants:
-#-------------------------------------------------------------------------
 
 # The image to use when the editor accepts files:
-file_image = ImageResource('file').create_image()
+file_image = ImageResource("file").create_image()
 
 # The image to use when the editor accepts objects:
-object_image = ImageResource('object').create_image()
+object_image = ImageResource("object").create_image()
 
 # The image to use when the editor is disabled:
-inactive_image = ImageResource('inactive').create_image()
+inactive_image = ImageResource("inactive").create_image()
 
 # String types:
-string_type = (str, six.text_type)
+string_type = (str, str)
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #  'SimpleEditor' class:
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 
 class SimpleEditor(Editor):
@@ -88,21 +67,16 @@ class SimpleEditor(Editor):
         source and a drop target.
     """
 
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Is the editor a drop target?
+    #: Is the editor a drop target?
     drop_target = Bool(True)
 
-    # Is the editor a drag source?
+    #: Is the editor a drag source?
     drag_source = Bool(True)
 
-    #-------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #-------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
@@ -110,9 +84,11 @@ class SimpleEditor(Editor):
         # Determine the drag/drop type:
         value = self.value
         self._is_list = isinstance(value, list)
-        self._is_file = (isinstance(value, string_type) or
-                         (self._is_list and (len(value) > 0) and
-                          isinstance(value[0], string_type)))
+        self._is_file = isinstance(value, string_type) or (
+            self._is_list
+            and (len(value) > 0)
+            and isinstance(value[0], string_type)
+        )
 
         # Get the right image to use:
         image = self.factory.image
@@ -131,9 +107,9 @@ class SimpleEditor(Editor):
         if disabled_image is not None:
             self._disabled_image = disabled_image.ConvertToBitmap()
         else:
-            data = numpy.reshape(numpy.fromstring(image.GetData(),
-                                                  numpy.uint8),
-                                 (-1, 3)) * numpy.array([[0.297, 0.589, 0.114]])
+            data = numpy.reshape(
+                numpy.fromstring(image.GetData(), numpy.uint8), (-1, 3)
+            ) * numpy.array([[0.297, 0.589, 0.114]])
             g = data[:, 0] + data[:, 1] + data[:, 2]
             data[:, 0] = data[:, 1] = data[:, 2] = g
             image.SetData(numpy.ravel(data.astype(numpy.uint8)).tostring())
@@ -142,35 +118,28 @@ class SimpleEditor(Editor):
 
         # Create the control and set up the event handlers:
         self.control = control = wx.Window(
-            parent, -1, size=wx.Size(image.GetWidth(), image.GetHeight()))
+            parent, -1, size=wx.Size(image.GetWidth(), image.GetHeight())
+        )
         self.set_tooltip()
 
         if self.drop_target:
             control.SetDropTarget(PythonDropTarget(self))
 
-        wx.EVT_LEFT_DOWN(control, self._left_down)
-        wx.EVT_LEFT_UP(control, self._left_up)
-        wx.EVT_MOTION(control, self._mouse_move)
-        wx.EVT_PAINT(control, self._on_paint)
-
-    #-------------------------------------------------------------------------
-    #  Disposes of the contents of an editor:
-    #-------------------------------------------------------------------------
+        control.Bind(wx.EVT_LEFT_DOWN, self._left_down)
+        control.Bind(wx.EVT_LEFT_UP, self._left_up)
+        control.Bind(wx.EVT_MOTION, self._mouse_move)
+        control.Bind(wx.EVT_PAINT, self._on_paint)
 
     def dispose(self):
         """ Disposes of the contents of an editor.
         """
         control = self.control
-        wx.EVT_LEFT_DOWN(control, None)
-        wx.EVT_LEFT_UP(control, None)
-        wx.EVT_MOTION(control, None)
-        wx.EVT_PAINT(control, None)
+        control.Unbind(wx.EVT_LEFT_DOWN)
+        control.Unbind(wx.EVT_LEFT_UP)
+        control.Unbind(wx.EVT_MOTION)
+        control.Unbind(wx.EVT_PAINT)
 
-        super(SimpleEditor, self).dispose()
-
-    #-------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #-------------------------------------------------------------------------
+        super().dispose()
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -178,11 +147,7 @@ class SimpleEditor(Editor):
         """
         return
 
-#-- Private Methods ------------------------------------------------------
-
-    #-------------------------------------------------------------------------
-    #  Returns the processed version of a drag request's data:
-    #-------------------------------------------------------------------------
+    # -- Private Methods ------------------------------------------------------
 
     def _get_drag_data(self, data):
         """ Returns the processed version of a drag request's data.
@@ -215,14 +180,10 @@ class SimpleEditor(Editor):
 
         return data
 
-    #-------------------------------------------------------------------------
-    #  Returns the unpickled version of a specified file (if possible):
-    #-------------------------------------------------------------------------
-
     def _unpickle(self, file_name):
         """ Returns the unpickled version of a specified file (if possible).
         """
-        with open(file_name, 'rb') as fh:
+        with open(file_name, "rb") as fh:
             try:
                 object = load(fh)
             except Exception:
@@ -230,7 +191,7 @@ class SimpleEditor(Editor):
 
         return object
 
-#-- wxPython Event Handlers ----------------------------------------------
+    # -- wxPython Event Handlers ----------------------------------------------
 
     def _on_paint(self, event):
         """ Called when the control needs repainting.
@@ -240,12 +201,13 @@ class SimpleEditor(Editor):
         if not control.IsEnabled():
             image = self._disabled_image
 
-        wdx, wdy = control.GetClientSizeTuple()
+        wdx, wdy = control.GetClientSize()
         wx.PaintDC(control).DrawBitmap(
             image,
-            (wdx - image.GetWidth()) / 2,
-            (wdy - image.GetHeight()) / 2,
-            True)
+            (wdx - image.GetWidth()) // 2,
+            (wdy - image.GetHeight()) // 2,
+            True,
+        )
 
     def _left_down(self, event):
         """ Handles the left mouse button being pressed.
@@ -269,8 +231,9 @@ class SimpleEditor(Editor):
         """ Handles the mouse being moved.
         """
         if self._x is not None:
-            if ((abs(self._x - event.GetX()) +
-                 abs(self._y - event.GetY())) >= 3):
+            if (
+                abs(self._x - event.GetX()) + abs(self._y - event.GetY())
+            ) >= 3:
                 self.control.ReleaseMouse()
                 self._x = None
                 if self._is_file:
@@ -280,11 +243,7 @@ class SimpleEditor(Editor):
 
         event.Skip()
 
-#----- Drag and drop event handlers: -------------------------------------
-
-    #-------------------------------------------------------------------------
-    #  Handles a Python object being dropped on the control:
-    #-------------------------------------------------------------------------
+    # ----- Drag and drop event handlers: -------------------------------------
 
     def wx_dropped_on(self, x, y, data, drag_result):
         """ Handles a Python object being dropped on the tree.
@@ -295,64 +254,45 @@ class SimpleEditor(Editor):
         except:
             return wx.DragNone
 
-    #-------------------------------------------------------------------------
-    #  Handles a Python object being dragged over the control:
-    #-------------------------------------------------------------------------
-
     def wx_drag_over(self, x, y, data, drag_result):
         """ Handles a Python object being dragged over the tree.
         """
         try:
-            self.object.base_trait(
-                self.name).validate(
-                self.object,
-                self.name,
-                self._get_drag_data(data))
+            self.object.base_trait(self.name).validate(
+                self.object, self.name, self._get_drag_data(data)
+            )
             return drag_result
         except:
             return wx.DragNone
 
-#-------------------------------------------------------------------------
-#  'CustomEditor' class:
-#-------------------------------------------------------------------------
-
 
 class CustomEditor(SimpleEditor):
     """ Custom style of drag-and-drop editor, which is not a drag source.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Is the editor a drag source? This value overrides the default.
+    #: Is the editor a drag source? This value overrides the default.
     drag_source = False
 
-#-------------------------------------------------------------------------
-#  'ReadonlyEditor' class:
-#-------------------------------------------------------------------------
-
 
 class ReadonlyEditor(SimpleEditor):
     """ Read-only style of drag-and-drop editor, which is not a drop target.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Is the editor a drop target? This value overrides the default.
+    #: Is the editor a drop target? This value overrides the default.
     drop_target = False
 
-#-------------------------------------------------------------------------
-#  'FileDropSource' class:
-#-------------------------------------------------------------------------
-
 
 class FileDropSource(wx.DropSource):
     """ Represents a draggable file.
     """
-    #-------------------------------------------------------------------------
-    #  Initializes the object:
-    #-------------------------------------------------------------------------
 
     def __init__(self, source, files):
         """ Initializes the object.
@@ -373,16 +313,10 @@ class FileDropSource(wx.DropSource):
             data_object.AddFile(file)
 
         # Create the drop source and begin the drag and drop operation:
-        super(FileDropSource, self).__init__(source)
+        super().__init__(source)
         self.SetData(data_object)
         self.result = self.DoDragDrop(True)
 
-    #-------------------------------------------------------------------------
-    #  Called when the data has been dropped:
-    #-------------------------------------------------------------------------
-
     def on_dropped(self, drag_result):
         """ Called when the data has been dropped. """
         return
-
-## EOF ########################################################################
